# -*- coding: utf-8 -*-
#COPYRIGHT 2017 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""The Conversion toolbox contains tools that convert data between
various formats."""
__all__ = ['ASCIIToRaster', 'AddCADFields', 'AddRasterToGeoPackage',
           'CADToGeodatabase', 'DEMToRaster', 'ExcelToTable', 'ExportCAD',
           'FeatureClassToFeatureClass', 'FeatureClassToGeodatabase',
           'FeatureClassToShapefile', 'FeatureToRaster', 'FeaturesToJSON',
           'FloatToRaster', 'GPXtoFeatures', 'JSONToFeatures', 'KMLToLayer',
           'LasDatasetToRaster', 'LayerToKML', 'MultipatchToCollada',
           'MultipatchToRaster', 'PointToRaster', 'PolygonToRaster',
           'PolylineToRaster', 'RasterToASCII', 'RasterToFloat',
           'RasterToGeodatabase', 'RasterToOtherFormat', 'RasterToPoint',
           'RasterToPolygon', 'RasterToPolyline', 'TableToDBASE',
           'TableToExcel', 'TableToGeodatabase', 'TableToTable',
           'WFSToFeatureClass']
__alias__ = 'conversion'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs, gptoolnotsupported
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Excel toolset
@gptooldoc('ExcelToTable_conversion', None)
def ExcelToTable(Input_Excel_File=None, Output_Table=None, Sheet=None):
    """ExcelToTable_conversion(Input_Excel_File, Output_Table, {Sheet})

        Converts Microsoft Excel files into a table.

     INPUTS:
      Input_Excel_File (File):
          The Microsoft Excel file to convert.
      Sheet {String}:
          The name of the particular sheet within the Excel file to import. If
          unspecified, the first sheet in the workbook will be used.

     OUTPUTS:
      Output_Table (Table):
          The output table."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExcelToTable_conversion(*gp_fixargs((Input_Excel_File, Output_Table, Sheet), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('TableToExcel_conversion', None)
def TableToExcel(Input_Table=None, Output_Excel_File=None, Use_field_alias_as_column_header=None, Use_domain_and_subtype_description=None):
    """TableToExcel_conversion(Input_Table, Output_Excel_File, {Use_field_alias_as_column_header}, {Use_domain_and_subtype_description})

        Converts a table to a Microsoft Excel file.

     INPUTS:
      Input_Table (Table View):
          The table to be converted to Microsoft Excel format.
      Use_field_alias_as_column_header {Boolean}:
          How column names in the output are determined.

          * NAME-Column headers will be set using the input's field names. This
          is the default.

          * ALIAS-Column headers will be set using the input geodatabase table's
          field aliases. If the input is a layer in a map, the value set on the
          layer's field alias is ignored.
      Use_domain_and_subtype_description {Boolean}:
          Controls how values from subtype fields or fields with a coded value
          domain are transferred to the output.

          * CODE-All field values will be used as they are stored in the table.
          This is the default.

          * DESCRIPTION-For subtype fields, the subtype description will be
          used. For fields with a coded value domain, the coded value
          descriptions will be used.

     OUTPUTS:
      Output_Excel_File (File):
          The output Microsoft Excel file."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.TableToExcel_conversion(*gp_fixargs((Input_Table, Output_Excel_File, Use_field_alias_as_column_header, Use_domain_and_subtype_description), True)))
        return retval
    except Exception as e:
        raise e


# From GPS toolset
@gptooldoc('GPXtoFeatures_conversion', None)
def GPXtoFeatures(Input_GPX_File=None, Output_Feature_class=None):
    """GPXtoFeatures_conversion(Input_GPX_File, Output_Feature_class)

        Converts the point information inside a GPX file into features.

     INPUTS:
      Input_GPX_File (File):
          The GPX file to convert.

     OUTPUTS:
      Output_Feature_class (Feature Class):
          The feature class to create."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GPXtoFeatures_conversion(*gp_fixargs((Input_GPX_File, Output_Feature_class), True)))
        return retval
    except Exception as e:
        raise e


# From Raster toolset
@gptooldoc('RasterToASCII_conversion', None)
def RasterToASCII(in_raster=None, out_ascii_file=None):
    """RasterToASCII_conversion(in_raster, out_ascii_file)

        Converts a raster dataset to an ASCII text file representing raster
        data.

     INPUTS:
      in_raster (Composite Geodataset):
          The input raster dataset.The raster can be integer or floating-point
          type.

     OUTPUTS:
      out_ascii_file (File):
          The output ASCII raster file."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RasterToASCII_conversion(*gp_fixargs((in_raster, out_ascii_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RasterToFloat_conversion', None)
def RasterToFloat(in_raster=None, out_float_file=None):
    """RasterToFloat_conversion(in_raster, out_float_file)

        Converts a raster dataset to a file of binary floating-point values
        representing raster data.

     INPUTS:
      in_raster (Composite Geodataset):
          The input raster dataset.The raster can be integer or floating-point
          type.

     OUTPUTS:
      out_float_file (File):
          The output floating-point raster file.The file name must have a .flt
          extension."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RasterToFloat_conversion(*gp_fixargs((in_raster, out_float_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RasterToPoint_conversion', None)
def RasterToPoint(in_raster=None, out_point_features=None, raster_field=None):
    """RasterToPoint_conversion(in_raster, out_point_features, {raster_field})

        Converts a raster dataset to point features.

     INPUTS:
      in_raster (Composite Geodataset):
          The input raster dataset.The raster can be integer or floating-point
          type.
      raster_field {Field}:
          The field to assign values from the cells in the input raster to the
          points in the output dataset.It can be an integer, floating point, or
          string field.

     OUTPUTS:
      out_point_features (Feature Class):
          The output feature class that will contain the converted points."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RasterToPoint_conversion(*gp_fixargs((in_raster, out_point_features, raster_field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RasterToPolygon_conversion', None)
def RasterToPolygon(in_raster=None, out_polygon_features=None, simplify=None, raster_field=None):
    """RasterToPolygon_conversion(in_raster, out_polygon_features, {simplify}, {raster_field})

        Converts a raster dataset to polygon features.

     INPUTS:
      in_raster (Composite Geodataset):
          The input raster dataset.The raster must be integer type.
      simplify {Boolean}:
          Determines if the output polygons will be smoothed into simpler shapes
          or conform to the input raster's cell edges.

          * SIMPLIFY-The polygons will be smoothed into simpler shapes. The
          smoothing is done in such a way that the polygons contain a minimum
          number of segments while remaining as close as possible the original
          raster cell edges. This is the default.

          * NO_SIMPLIFY-The edge of the polygons will conform exactly to the
          input raster's cell edges. With this option, converting the resulting
          polygon feature class back to a raster would produce a raster the same
          as the original.
      raster_field {Field}:
          The field used to assign values from the cells in the input raster to
          the polygons in the output dataset.It can be an integer or a string
          field.

     OUTPUTS:
      out_polygon_features (Feature Class):
          The output feature class that will contain the converted polygons."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RasterToPolygon_conversion(*gp_fixargs((in_raster, out_polygon_features, simplify, raster_field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RasterToPolyline_conversion', None)
def RasterToPolyline(in_raster=None, out_polyline_features=None, background_value=None, minimum_dangle_length=None, simplify=None, raster_field=None):
    """RasterToPolyline_conversion(in_raster, out_polyline_features, {background_value}, {minimum_dangle_length}, {simplify}, {raster_field})

        Converts a raster dataset to polyline features.

     INPUTS:
      in_raster (Composite Geodataset):
          The input raster dataset.The raster must be integer type.
      background_value {String}:
          Specifies the value that will identify the background cells. The
          raster dataset is viewed as a set of foreground cells and background
          cells. The linear features are formed from the foreground cells.

          * ZERO-The background is composed of cells of zero or less or NoData.
          All cells with a value greater than zero are considered a foreground
          value.

          * NODATA-The background is composed of NoData cells. All cells with
          valid values belong to the foreground.
      minimum_dangle_length {Double}:
          Minimum length of dangling polylines that will be retained. The
          default is zero.
      simplify {Boolean}:
          Simplifies a line by removing small fluctuations or extraneous bends
          from it while preserving its essential shape.

          * SIMPLIFY-The polylines will be simplified into simpler shapes such
          that each contains a minimum number of segments. This is the default.

          * NO_SIMPLIFY-The polylines will not be simplified.
      raster_field {Field}:
          The field used to assign values from the cells in the input raster to
          the polyline features in the output dataset.It can be an integer or a
          string field.

     OUTPUTS:
      out_polyline_features (Feature Class):
          The output feature class that will contain the converted polylines."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RasterToPolyline_conversion(*gp_fixargs((in_raster, out_polyline_features, background_value, minimum_dangle_length, simplify, raster_field), True)))
        return retval
    except Exception as e:
        raise e


# From WFS toolset
@gptooldoc('WFSToFeatureClass_conversion', None)
def WFSToFeatureClass(input_WFS_server=None, WFS_feature_type=None, out_path=None, out_name=None):
    """WFSToFeatureClass_conversion(input_WFS_server, WFS_feature_type, out_path, out_name)

        Imports a feature type from a web feature service (WFS) to a feature
        class in a geodatabase.

     INPUTS:
      input_WFS_server (String):
          The URL of the source WFS service.
      WFS_feature_type (String):
          The name of the feature type to extract from the input WFS service.
      out_path (Workspace / Feature Dataset):
          The output location can be the root level of a geodatabase or a
          feature dataset within a geodatabase. If the output location is a
          feature dataset, the coordinates are converted from the source
          coordinate system to the coordinate system of the feature dataset.
      out_name (String):
          The name of the feature class to create within the output location. If
          the feature class name already exists in the geodatabase, the name
          will be auto-incremented. By default, the feature type name is used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.WFSToFeatureClass_conversion(*gp_fixargs((input_WFS_server, WFS_feature_type, out_path, out_name), True)))
        return retval
    except Exception as e:
        raise e


# JSON toolset
@gptooldoc('FeaturesToJSON_conversion', None)
def FeaturesToJSON(in_features=None, out_json_file=None, format_json=None, include_z_values=None, include_m_values=None, geoJSON=None):
    """FeaturesToJSON_conversion(in_features, out_json_file, {format_json}, {include_z_values}, {include_m_values}, {geoJSON})

        Converts features to JSON format. The fields, geometry, and spatial
        reference of features will be converted to their corresponding JSON
        representation and written to a file with a .json extension.

     INPUTS:
      in_features (Feature Layer):
          The features to convert to JSON.
      format_json {Boolean}:
          The JSON can be formatted to improve human readability similar to
          ArcGIS REST API specification's PJSON (Pretty JSON) format.

          * NOT_FORMATTED-The features will not be formatted. This is the
          default.

          * FORMATTED-The features will be formatted to improve human
          readability.
      include_z_values {Boolean}:
          Include Z value of the features to the JSON.

          * NO_Z_VALUES-The Z values will not be included in geometries and the
          hasZ property of the JSON will not be included. This is the default.

          * Z_VALUES-The Z values will be included in geometries and the hasZ
          property of the JSON will be set to True.
      include_m_values {Boolean}:
          Include M value of the features to the JSON.

          * NO_M_VALUES-The M values will not be included in geometries and the
          hasM property of the JSON will not be included. This is the default.

          * M_VALUES-The M values will be included in geometries and the hasM
          property of the JSON will be set to True.
      geoJSON {Boolean}:
          Create output as GeoJSON, confirming to the GeoJSON specification.

          * GEOJSON-The output will be created as geo JSON.

          * NO_GEOJSON-The output will be created as esri JSON. This is the
          default.

     OUTPUTS:
      out_json_file (File):
          The output JSON file."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FeaturesToJSON_conversion(*gp_fixargs((in_features, out_json_file, format_json, include_z_values, include_m_values, geoJSON), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('JSONToFeatures_conversion', None)
def JSONToFeatures(in_json_file=None, out_features=None):
    """JSONToFeatures_conversion(in_json_file, out_features)

        Converts JSON features based on ArcGIS REST API specification into a
        feature class. The feature class will have fields, geometry type, and
        spatial reference as defined in the JSON.

     INPUTS:
      in_json_file (File):
          The JSON file (.json) to convert.

     OUTPUTS:
      out_features (Feature Class):
          The output feature class to create."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.JSONToFeatures_conversion(*gp_fixargs((in_json_file, out_features), True)))
        return retval
    except Exception as e:
        raise e


# KML toolset
@gptoolnotsupported
@gptooldoc('KMLToLayer_conversion', None)
def KMLToLayer(in_kml_file=None, output_folder=None, output_data=None, include_groundoverlay=None):
    """KMLToLayer_conversion(in_kml_file, output_folder, {output_data}, {include_groundoverlay})

        Converts a KML or KMZ file into feature classes and a layer file. The
        layer file maintains the symbology found within the original KML or
        KMZ file.

     INPUTS:
      in_kml_file (File / KML Layer):
          The KML or KMZ file to translate.
      output_folder (Folder):
          The destination folder for the file geodatabase and layer (.lyrx)
          file.
      output_data {String}:
          The name of the output file geodatabase and layer file. The default
          is the name of the input KML file.
      include_groundoverlay {Boolean}:
          Include ground overlay (raster, air photos, and so on). Use caution if
          the KMZ points to a service that serves raster imagery. The tool will
          attempt to translate the raster imagery at all available scales. This
          process could be lengthy and possibly overwhelm the service.

          * GROUNDOVERLAY-Ground overlays are included in the output.

          * NO_GROUNDOVERLAY-Ground overlays are not included in the output.
          This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.KMLToLayer_conversion(*gp_fixargs((in_kml_file, output_folder, output_data, include_groundoverlay), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('LayerToKML_conversion', None)
def LayerToKML(layer=None, out_kmz_file=None, layer_output_scale=None, is_composite=None, boundary_box_extent=None, image_size=None, dpi_of_client=None, ignore_zvalue=None):
    """LayerToKML_conversion(layer, out_kmz_file, {layer_output_scale}, {is_composite}, {boundary_box_extent}, {image_size}, {dpi_of_client}, {ignore_zvalue})

        This tool converts a feature or raster layer into a KML file
        containing a translation of Esri geometries and symbology. This file
        is compressed using ZIP compression, has a .kmz extension, and can be
        read by any KML client including ArcGIS Explorer, ArcGlobe, and Google
        Earth.

     INPUTS:
      layer (Layer):
          The feature or raster layer or layer file (.lyrx) to be converted to
          KML.
      layer_output_scale {Double}:
          The scale at which to export the layer. This parameter is used with
          any scale dependency, such as layer visibility or scale-dependent
          rendering. If the layer is not visible at the export scale, it will
          not be included in the created KML file. Any value, such as 0, can be
          used if there are no scale dependencies.If exporting a layer that is
          to be displayed as 3D vectors and the
          is_composite parameter is set to NO_COMPOSITE, you can set this
          parameter to any value, as long as your features do not have any
          scale-dependent rendering.Only numeric characters should be entered;
          for example, enter 20000 as
          the scale, not 1:20000 or 20,000.
      is_composite {Boolean}:
          * COMPOSITE-The output KML file will be a single composite image
          representing the raster or vector features in the source layer. The
          raster is draped over the terrain as a KML GroundOverlay. Select this
          option to reduce the size of the output KMZ file. When you check this
          box, individual features and layers in the KML are not selectable.

          * NO_COMPOSITE-If your layer has vector features, they are preserved
          as KML vectors. If your layer is a raster, you can choose either
          option for this parameter without any visual difference.
      boundary_box_extent {Extent}:
          The geographic extent of the area to be exported. The extent
          rectangle bounds should be specified as a space-delimited string of
          WGS84 geographic coordinates in the form lower left and upper right
          (xmin, ymin, xmax, ymax).
      image_size {Long}:
          Defines the vertical and horizontal resolution when the Return single
          composite image parameter is used. Use this parameter with the DPI
          parameter to control output image resolution.This parameter does not
          provide the ability to resample source
          rasters. Any input rasters will have a snapshot taken and included in
          the KML output as a simple .PNG image.
      dpi_of_client {Long}:
          Defines the device resolution for KML output when the Return single
          composite image parameter is used. Use this parameter with the
          image_size parameter to control output image resolution.This parameter
          does not provide the ability to resample source
          rasters. Any input rasters will have a snapshot taken and included in
          the KML output as a simple .PNG image.
      ignore_zvalue {Boolean}:
          * ABSOLUTE-Use the Z-values of features when creating KML. The
          features will be drawn inside KML clients relative to sea level.

          * CLAMPED_TO_GROUND-Override Z-values in your features and create KML
          with the features clamped to the ground. The features will be draped
          over the terrain. This setting is used for features that do not have
          Z-values. This is the default.

     OUTPUTS:
      out_kmz_file (File):
          The KML file to write. This file is compressed and has a .kmz
          extension. It can be read by any KML client including ArcGIS Explorer,
          ArcGlobe, and Google Earth."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.LayerToKML_conversion(*gp_fixargs((layer, out_kmz_file, layer_output_scale, is_composite, boundary_box_extent, image_size, dpi_of_client, ignore_zvalue), True)))
        return retval
    except Exception as e:
        raise e


# To CAD toolset
@gptoolnotsupported
@gptooldoc('AddCADFields_conversion', None)
def AddCADFields(input_table=None, Entities=None, LayerProps=None, TextProps=None, DocProps=None, XDataProps=None):
    """AddCADFields_conversion(input_table, Entities, {LayerProps}, {TextProps}, {DocProps}, {XDataProps})

        Adds several reserved CAD fields in one step. Fields created by this
        tool are used by the Export To CAD tool to generate CAD entities with
        specific properties.  After executing this tool, you must calculate or
        type the appropriate field values.

     INPUTS:
      input_table (Table View):
          Input table, feature class, or shapefile that will have the CAD-
          specific fields added to it
      Entities (Boolean):
          Adds the list of CAD-specific Entity property fields to the input
          table

          * ADD_ENTITY_PROPERTIES-Adds the list of CAD-specific Entity property
          fields to the input table

          * NO_ENTITY_PROPERTIES-Does not add the list of CAD-specific Entity
          property fields to the input table
      LayerProps {Boolean}:
          Adds the list of CAD-specific Layer property fields to the input table

          * ADD_LAYER_PROPERTIES-Adds the list of CAD-specific Layer property
          fields to the input table

          * NO_LAYER_PROPERTIES-Does not add the list of CAD-specific Layer
          property fields to the input table
      TextProps {Boolean}:
          Adds the list of CAD-specific Text property fields to the input table

          * ADD_TEXT_PROPERTIES-Adds the list of CAD-specific Text property
          fields to the input table

          * NO_TEXT_PROPERTIES-Does not add the list of CAD-specific Text
          property fields to the input table
      DocProps {Boolean}:
          Adds the list of CAD-specific Document property fields to the input
          table

          * ADD_DOCUMENT_PROPERTIES-Adds the list of CAD-specific Document
          property fields to the input table

          * NO_DOCUMENT_PROPERTIES-Does not add the list of CAD-specific
          Document property fields to the input table
      XDataProps {Boolean}:
          Adds the list of CAD-specific XData property fields to the input table

          * ADD_XDATA_PROPERTIES-Adds the list of CAD-specific XData property
          fields to the input table

          * NO_XDATA_PROPERTIES-Does not add the list of CAD-specific XData
          property fields to the input table"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddCADFields_conversion(*gp_fixargs((input_table, Entities, LayerProps, TextProps, DocProps, XDataProps), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('ExportCAD_conversion', None)
def ExportCAD(in_features=None, Output_Type=None, Output_File=None, Ignore_FileNames=None, Append_To_Existing=None, Seed_File=None):
    """ExportCAD_conversion(in_features;in_features..., Output_Type, Output_File, {Ignore_FileNames}, {Append_To_Existing}, {Seed_File})

        Creates one or more CAD drawings based on the values contained in one
        or more input feature classes or feature layers and supporting tables.

     INPUTS:
      in_features (Feature Layer):
          A collection of feature classes and/or feature layers whose geometry
          will be exported to one or more CAD files.
      Output_Type (String):
          The CAD platform and file version of the output files. This value
          overrides any Output_Type values contained in the keyname column or
          alias column CADFile_type.

          * DGN_V8-Microstation DGN file

          * DWG_R2013-DWG version 2013

          * DWG_R2010-DWG version 2010

          * DWG_R2007-DWG version 2007

          * DWG_R2005-DWG version 2005

          * DWG_R2004-DWG version 2004

          * DWG_R2000-DWG version 2000

          * DWG_R14-DWG version 14

          * DXF_R2013-DXF version 2013

          * DXF_R2010-DXF version 2010

          * DXF_R2007-DXF version 2007

          * DXF_R2005-DXF version 2005

          * DXF_R2004-DXF version 2004

          * DXF_R2000-DXF version 2000

          * DXF_R14-DXF version 14
      Ignore_FileNames {Boolean}:
          Allows the function to ignore or use the paths in the DrawingPathName.
          This allows the function to output CAD entities to specific drawings
          or ignore this and add to one CAD file.

          * Ignore_Filenames_in_Tables-Ignores the paths in the document entity
          fields and allows the output of all entities to a single CAD file.

          * Use_Filenames_in_Tables-Allows the paths in the document entity
          fields to be used and have each entity's path used so that each CAD
          part will be written to a separate file. This is the default.
      Append_To_Existing {Boolean}:
          Allows the output to append to an existing CAD file. This allows you
          to add information to a CAD file on disk.

          * Append_To_Existing_Files-Allows the output file content to be added
          to an existing output CAD file. The existing CAD file content will not
          be lost.

          * Overwrite_Existing_Files-The output file content will overwrite the
          existing CAD file content. This is the default.
      Seed_File {CAD Drawing Dataset}:
          An existing CAD drawing whose contents and document and layer
          properties will be used for all new output CAD files. The CAD platform
          and format version of the seed file overrides the value specified by
          the Output_Type parameter. If appending to existing CAD files, the
          seed drawing is ignored.

     OUTPUTS:
      Output_File (CAD Drawing Dataset):
          The path of the desired output CAD drawing file. This name overrides
          any drawing name information included in the input features columns or
          alias columns named DrawingPathName."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportCAD_conversion(*gp_fixargs((in_features, Output_Type, Output_File, Ignore_FileNames, Append_To_Existing, Seed_File), True)))
        return retval
    except Exception as e:
        raise e


# To Collada toolset
@gptoolnotsupported
@gptooldoc('MultipatchToCollada_conversion', None)
def MultipatchToCollada(in_features=None, output_folder=None, prepend_source=None, field_name=None):
    """MultipatchToCollada_conversion(in_features, output_folder, {prepend_source}, {field_name})

        Converts one or more multipatch features into a collection of COLLADA
        (.dae) files and referenced texture image files in an output folder.
        The inputs can be a layer or a feature class.

     INPUTS:
      in_features (Feature Layer):
          The multipatch features to be exported.
      prepend_source {Boolean}:
          Prepend the file names of the output COLLADA files with the name of
          the source feature layer.

          * PREPEND_SOURCE_NAME-Prepend the file names.

          * PREPEND_NONE-Do not prepend the file names. This is the default.
      field_name {Field}:
          The feature attribute to use as the output COLLADA file name for each
          exported feature. If no field is specified, the feature's Object ID is
          used.

     OUTPUTS:
      output_folder (Folder):
          The destination folder where the output COLLADA files and texture
          image files will be placed."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MultipatchToCollada_conversion(*gp_fixargs((in_features, output_folder, prepend_source, field_name), True)))
        return retval
    except Exception as e:
        raise e


# To GeoPackage toolset
@gptoolnotsupported
@gptooldoc('AddRasterToGeoPackage_conversion', None)
def AddRasterToGeoPackage(in_dataset=None, target_geopackage=None, raster_name=None, tiling_scheme=None, tiling_scheme_file=None):
    """AddRasterToGeoPackage_conversion(in_dataset, target_geopackage, raster_name, {tiling_scheme}, {tiling_scheme_file})

        Load raster datasets into an OGC GeoPackage raster pyramid.

     INPUTS:
      in_dataset (Raster Layer / Mosaic Layer):
          The raster dataset to load into the OGC GeoPackage raster pyramid.
      target_geopackage (File / Workspace):
          The target GeoPackage.
      raster_name (String):
          The name of the output GeoPackage raster pyramid.
      tiling_scheme {String}:
          The tiling scheme used.

          * TILED-The spatial reference of the input raster will be maintained
          and tiles will be generated consistent with the GeoPackage standard.
          This is the default.

          * ARCGISONLINE_SCHEME-Generate raster tiles in a Web Mercator
          coordinate reference (the same scheme developed for the Army
          Geospatial Center).

          * NSGPROFILE-A scaled transverse Mercator is used.

          * GOOGLE_EARTH_WEB_MERCATOR-Create raster tiles using the parameters
          in the Web Mercator coordinate reference.

          * FROM_FILE-Uses a custom tiling scheme from a file using an XML
          schema definition created using the Generate Tile Cache Tiling Scheme
          tool.
      tiling_scheme_file {File}:
          A custom tiling scheme file that is required when tiling_scheme is
          set to FROM_FILE."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddRasterToGeoPackage_conversion(*gp_fixargs((in_dataset, target_geopackage, raster_name, tiling_scheme, tiling_scheme_file), True)))
        return retval
    except Exception as e:
        raise e


# To Geodatabase toolset
@gptoolnotsupported
@gptooldoc('CADToGeodatabase_conversion', None)
def CADToGeodatabase(input_cad_datasets=None, out_gdb_path=None, out_dataset_name=None, reference_scale=None, spatial_reference=None):
    """CADToGeodatabase_conversion(input_cad_datasets;input_cad_datasets..., out_gdb_path, out_dataset_name, reference_scale, {spatial_reference})

        Reads a CAD dataset and creates feature classes of the drawing. The
        feature classes are written to a geodatabase feature dataset.

     INPUTS:
      input_cad_datasets (CAD Drawing Dataset):
          The collection of CAD files to convert to geodatabase features.
      out_gdb_path (Workspace):
          The geodatabase where the output feature dataset will be created.
          This geodatabase must already exist.
      out_dataset_name (String):
          The name of the feature dataset to be created.
      reference_scale (Double):
          This parameter is not needed for this tool as CAD annotation is
          treated as points in ArcGIS Pro.
      spatial_reference {Spatial Reference}:
          The spatial reference of the output feature dataset. If you wish to
          control other aspects of the spatial reference, such as the xy, z, m
          domains, resolutions, and tolerances, set the appropriate
          geoprocessing environments."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CADToGeodatabase_conversion(*gp_fixargs((input_cad_datasets, out_gdb_path, out_dataset_name, reference_scale, spatial_reference), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FeatureClassToFeatureClass_conversion', None)
def FeatureClassToFeatureClass(in_features=None, out_path=None, out_name=None, where_clause=None, field_mapping=None, config_keyword=None):
    """FeatureClassToFeatureClass_conversion(in_features, out_path, out_name, {where_clause}, {field_mapping}, {config_keyword})

        Converts a shapefile, coverage feature class, or geodatabase feature
        class to a shapefile or geodatabase feature class.

     INPUTS:
      in_features (Feature Layer):
          The feature class or feature layer that will be converted.
      out_path (Workspace / Feature Dataset):
          The location in which the output feature class will be created. This
          can be either a geodatabase or a folder. If the output location is a
          folder, the output will be a shapefile.
      out_name (String):
          The name of the output feature class.
      where_clause {SQL Expression}:
          An SQL expression used to select a subset of features. For more
          information on SQL syntax see the help topic SQL reference for
          elements used in query expressions.
      field_mapping {Field Mappings}:
          The fields and field contents chosen from the input feature class. You
          can add, rename, or delete output fields as well as set properties
          such as data type and merge rule.You can use the ArcPy FieldMappings
          class to define this parameter.
      config_keyword {String}"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FeatureClassToFeatureClass_conversion(*gp_fixargs((in_features, out_path, out_name, where_clause, field_mapping, config_keyword), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FeatureClassToGeodatabase_conversion', None)
def FeatureClassToGeodatabase(Input_Features=None, Output_Geodatabase=None):
    """FeatureClassToGeodatabase_conversion(Input_Features;Input_Features..., Output_Geodatabase)

        Converts one or more feature classes or feature layers to geodatabase
        feature classes.

     INPUTS:
      Input_Features (Feature Layer):
          One or more feature classes or feature layers to be imported into a
          file or enterprise geodatabase.
      Output_Geodatabase (Workspace / Feature Dataset):
          The output or destination geodatabase. This can be a file or
          enterprise geodatabase."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FeatureClassToGeodatabase_conversion(*gp_fixargs((Input_Features, Output_Geodatabase), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RasterToGeodatabase_conversion', None)
def RasterToGeodatabase(Input_Rasters=None, Output_Geodatabase=None, Configuration_Keyword=None):
    """RasterToGeodatabase_conversion(Input_Rasters;Input_Rasters..., Output_Geodatabase, {Configuration_Keyword})

        Loads multiple raster datasets into a geodatabase.

     INPUTS:
      Input_Rasters (Raster Dataset):
          Input raster dataset(s).
      Output_Geodatabase (Workspace):
          The path and name of a geodatabase.
      Configuration_Keyword {String}:
          Specifies the storage parameters (configuration) for a geodatabase.
          Configuration keywords are set up by your database administrator."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RasterToGeodatabase_conversion(*gp_fixargs((Input_Rasters, Output_Geodatabase, Configuration_Keyword), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('TableToGeodatabase_conversion', None)
def TableToGeodatabase(Input_Table=None, Output_Geodatabase=None):
    """TableToGeodatabase_conversion(Input_Table;Input_Table..., Output_Geodatabase)

        Converts one or more tables to geodatabase tables in an output
        geodatabase. The inputs can be dBASE, INFO, VPF, OLE DB tables,
        geodatabase tables, or table views.

     INPUTS:
      Input_Table (Table View):
          The list of tables to be converted to geodatabase tables. Input tables
          can be INFO, dBASE, OLE DB, geodatabase tables, or table views.
      Output_Geodatabase (Workspace):
          The destination geodatabase where the tables will be placed."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.TableToGeodatabase_conversion(*gp_fixargs((Input_Table, Output_Geodatabase), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('TableToTable_conversion', None)
def TableToTable(in_rows=None, out_path=None, out_name=None, where_clause=None, field_mapping=None, config_keyword=None):
    """TableToTable_conversion(in_rows, out_path, out_name, {where_clause}, {field_mapping}, {config_keyword})

        Converts an input table to a dBASE or geodatabase table.

     INPUTS:
      in_rows (Table View / Raster Layer):
          The input table to be converted to a new table.
      out_path (Workspace / Feature Dataset):
          The destination where the output table will be written.
      out_name (String):
          The name of the output table. If the output location is a folder,
          convert the input rows to a dBASE
          table by specifying a name with the extension .dbf. If the output
          location is a geodatabase, convert the input rows to a geodatabase
          table by specifying a name with no extension.
      where_clause {SQL Expression}:
          An SQL expression used to select a subset of records. Learn more about
          SQL query expressions
      field_mapping {Field Mappings}:
          The fields and field contents chosen from the input table. You can
          add, rename, or delete output fields as well as set properties such as
          data type and merge rule.. Learn more about choosing and setting the
          output fieldsYou can use the ArcPy FieldMappings object for this
          parameter.
      config_keyword {String}:
          Specifies the default storage parameters (configurations) for
          geodatabases in a relational database management system (RDBMS). This
          setting is applicable only when using enterprise geodatabase
          tables.Configuration keywords are set by the database administrator."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.TableToTable_conversion(*gp_fixargs((in_rows, out_path, out_name, where_clause, field_mapping, config_keyword), True)))
        return retval
    except Exception as e:
        raise e


# To Raster toolset
@gptooldoc('ASCIIToRaster_conversion', None)
def ASCIIToRaster(in_ascii_file=None, out_raster=None, data_type=None):
    """ASCIIToRaster_conversion(in_ascii_file, out_raster, {data_type})

        Converts an ASCII file representing raster data to a raster dataset.

     INPUTS:
      in_ascii_file (File):
          The input ASCII file to be converted.
      data_type {String}:
          The data type of the output raster dataset.

          * INTEGER-An integer raster dataset will be created.

          * FLOAT-A floating-point raster dataset will be created.

     OUTPUTS:
      out_raster (Raster Dataset):
          The output raster dataset to be created.When not saving to a
          geodatabase, specify .tif for a TIFF file format,
          .img for an ERDAS IMAGINE file format, or no extension for an Esri
          Grid raster format."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ASCIIToRaster_conversion(*gp_fixargs((in_ascii_file, out_raster, data_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DEMToRaster_conversion', None)
def DEMToRaster(in_dem_file=None, out_raster=None, data_type=None, z_factor=None):
    """DEMToRaster_conversion(in_dem_file, out_raster, {data_type}, {z_factor})

        Converts a digital elevation model (DEM) in a United States Geological
        Survey (USGS) format to a raster dataset.

     INPUTS:
      in_dem_file (File):
          The input USGS DEM file. The DEM must be standard USGS 7.5 minute, 1
          degree, or any other file in the USGS DEM format. The DEM may be in
          either fixed or variable record-length format.
      data_type {String}:
          Data type of the output raster dataset.

          * INTEGER-An integer raster dataset will be created.

          * FLOAT-A floating-point raster dataset will be created. This is the
          default.
      z_factor {Double}:
          The number of ground x,y units in one surface z unit.The z-factor
          adjusts the units of measure for the z units when they
          are different from the x,y units of the input surface. The z-values of
          the input surface are multiplied by the z-factor when calculating the
          final output surface.If the x,y units and z units are in the same
          units of measure, the
          z-factor is 1. This is the default.If the x,y units and z units are in
          different units of measure, the
          z-factor must be set to the appropriate factor, or the results will be
          incorrect. For example, if your z units are feet and your x,y units
          are meters, you would use a z-factor of 0.3048 to convert your z units
          from feet to meters (1 foot = 0.3048 meter).

     OUTPUTS:
      out_raster (Raster Dataset):
          The output raster dataset to be created.When not saving to a
          geodatabase, specify .tif for a TIFF file format,
          .img for an ERDAS IMAGINE file format, or no extension for an Esri
          Grid raster format."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DEMToRaster_conversion(*gp_fixargs((in_dem_file, out_raster, data_type, z_factor), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FeatureToRaster_conversion', None)
def FeatureToRaster(in_features=None, field=None, out_raster=None, cell_size=None):
    """FeatureToRaster_conversion(in_features, field, out_raster, {cell_size})

        Converts features to a raster dataset.

     INPUTS:
      in_features (Composite Geodataset):
          The input feature dataset to be converted to a raster dataset.
      field (Field):
          The field used to assign values to the output raster.It can be any
          field of the input feature dataset's attribute table.If the Shape
          field of a point or multipoint dataset contains z or m
          values, then either of these can be used.
      cell_size {Analysis Cell Size}:
          The cell size for the output raster dataset.The default cell size is
          the shortest of the width or height of the
          extent of the input feature dataset, in the output spatial reference,
          divided by 250.

     OUTPUTS:
      out_raster (Raster Dataset):
          The output raster dataset to be created.When not saving to a
          geodatabase, specify .tif for a TIFF file format,
          .img for an ERDAS IMAGINE file format, or no extension for an Esri
          Grid raster format."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FeatureToRaster_conversion(*gp_fixargs((in_features, field, out_raster, cell_size), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FloatToRaster_conversion', None)
def FloatToRaster(in_float_file=None, out_raster=None):
    """FloatToRaster_conversion(in_float_file, out_raster)

        Converts a file of binary floating-point values representing raster
        data to a raster dataset.

     INPUTS:
      in_float_file (File):
          The input floating-point binary file. The file must have a .flt
          extension. There must be a header file in
          association with the floating-point binary file, with a .hdr
          extension.

     OUTPUTS:
      out_raster (Raster Dataset):
          The output raster dataset to be created.When not saving to a
          geodatabase, specify .tif for a TIFF file format,
          .img for an ERDAS IMAGINE file format, or no extension for an Esri
          Grid raster format."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FloatToRaster_conversion(*gp_fixargs((in_float_file, out_raster), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('LasDatasetToRaster_conversion', None)
def LasDatasetToRaster(in_las_dataset=None, out_raster=None, value_field=None, interpolation_type=None, data_type=None, sampling_type=None, sampling_value=None, z_factor=None):
    """LasDatasetToRaster_conversion(in_las_dataset, out_raster, {value_field}, {interpolation_type}, {data_type}, {sampling_type}, {sampling_value}, {z_factor})

        Creates a raster using elevation, intensity, or RGB values stored in
        the lidar points referenced by the LAS dataset.

     INPUTS:
      in_las_dataset (LAS Dataset Layer):
          The LAS dataset to process.
      value_field {String}:
          The lidar data that will be used to generate the raster output.

          * ELEVATION-Elevation from the lidar files will be used to create the
          raster. This is the default.

          * INTENSITY-Intensity information from the lidar files will be used to
          create the raster.

          * RGB-RGB values from the lidar points will be used to create 3-band
          imagery.
      interpolation_type {Interpolate}:
          The interpolation technique that will be used to determine the cell
          values of the output raster.The binning approach provides a Cell
          Assignment Method for determining
          each output cell using the points that fall within its extent, along
          with a Void Fill Method to determine the value of cells that do not
          contain any LAS points.Cell Assignment Methods

          * AVERAGE-Assigns the average value of all points in the cell. This is
          the default.

          * MINIMUM-Assigns the minimum value found in the points within the
          cell.

          * MAXIMUM-Assigns the maximum value found in the points within the
          cell.

          * IDW-Uses Inverse Distance Weighted interpolation to determine the
          cell value.

          * NEAREST-Uses Nearest Neighbor assignment to determine the cell
          value.
          Void Fill Methods

          * NONE-NoData is assigned to the cell.

          * SIMPLE-Averages the values from data cells immediately surrounding a
          NoData cell to eliminate small voids.

          * LINEAR-Triangulates across void areas and uses linear interpolation
          on the triangulated value to determine the cell value. This is the
          default.

          * NATURAL_NEIGHBOR-Uses natural neighbor interpolation to determine
          the cell value.
          The Triangulation interpolation methods derive cell values using a TIN
          based approach while also offering the opportunity to speed up
          processing time by thinning the sampling of LAS data using the Window
          Size technique.Triangulation Methods

          * Linear-Uses linear interpolation to determine cell values.

          * Natural Neighbors-Uses natural neighbor interpolation to determine
          cell value.
          Window Size Selection Methods

          * Maximum-The point with the highest value in each window size is
          maintained. This is the default.

          * Minimum-The point with the lowest value in each window size is
          maintained.

          * Closest To Mean-The point whose value is closest to the average of
          all point values in the window size is maintained.
      data_type {String}:
          The data type of the output raster can be defined by the following
          keywords:

          * FLOAT-Output raster will use 32-bit floating point, which supports
          values ranging from -3.402823466e+38 to 3.402823466e+38. This is the
          default.

          * INT-Output raster will use an appropriate integer bit depth. This
          option will round Z-values to the nearest whole number and write an
          integer to each raster cell value.
      sampling_type {String}:
          Specifies the method used for interpreting the Sampling Value to
          define the resolution of the output raster.

          * OBSERVATIONS-Defines the number of cells that divide the lengthiest
          side of the LAS dataset extent.

          * CELLSIZE-Defines the cell size of the output raster. This is the
          default.
      sampling_value {Double}:
          Specifies the value used in conjunction with the Sampling Type to
          define the resolution of the output raster.
      z_factor {Double}:
          The factor by which Z values will be multiplied. This is typically
          used to convert Z linear units to match XY linear units. The default
          is 1, which leaves elevation values unchanged.

     OUTPUTS:
      out_raster (Raster Dataset):
          The location and name of the
          output raster. When storing a raster dataset in a geodatabase or in a
          folder such as an Esri Grid, no file
          extension should be added to the name of the raster dataset. A file
          extension can be provided to define the raster's format when storing
          it in a folder, such as .tif to generate a GeoTIFF or .img to generate
          an ERDAS IMAGINE format file.
          If the raster is stored as a
          TIFF file or in a geodatabase, its raster compression type and quality
          can be specified using geoprocessing environment settings."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.LasDatasetToRaster_conversion(*gp_fixargs((in_las_dataset, out_raster, value_field, interpolation_type, data_type, sampling_type, sampling_value, z_factor), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('MultipatchToRaster_conversion', None)
def MultipatchToRaster(in_multipatch_features=None, out_raster=None, cell_size=None):
    """MultipatchToRaster_conversion(in_multipatch_features, out_raster, {cell_size})

        Converts multipatch features to a raster dataset.

     INPUTS:
      in_multipatch_features (Composite Geodataset):
          The input multipatch features to be converted to a raster.
      cell_size {Analysis Cell Size}:
          The cell size for the output raster dataset.The default cell size is
          the shortest of the width or height of the
          extent of the input feature dataset, in the output spatial reference,
          divided by 250.

     OUTPUTS:
      out_raster (Raster Dataset):
          The output raster dataset to be created.It will be of floating point
          type.When not saving to a geodatabase, specify .tif for a TIFF file
          format,
          .img for an ERDAS IMAGINE file format, or no extension for an Esri
          Grid raster format."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MultipatchToRaster_conversion(*gp_fixargs((in_multipatch_features, out_raster, cell_size), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('PointToRaster_conversion', None)
def PointToRaster(in_features=None, value_field=None, out_rasterdataset=None, cell_assignment=None, priority_field=None, cellsize=None):
    """PointToRaster_conversion(in_features, value_field, out_rasterdataset, {cell_assignment}, {priority_field}, {cellsize})

        Converts point features to a raster dataset.

     INPUTS:
      in_features (Feature Layer):
          The point or multipoint input feature dataset to be converted to a
          raster.
      value_field (Field):
          The field used to assign values to the output raster.It can be any
          field of the input feature dataset's attribute table.If the Shape
          field of a point or multipoint dataset contains z or m
          values, then either of these can be used.
      cell_assignment {String}:
          The method to determine how the cell will be assigned a value when
          more than one feature falls within a cell.

          * MOST_FREQUENT-If there is more than one feature within the cell, the
          one with the most common attribute, in the Value field, is assigned to
          the cell. If they have the same number of common attributes, the one
          with the lowest FID is used.

          * SUM-The sum of the attributes of all the points within the cell (not
          valid for string data).

          * MEAN-The mean of the attributes of all the points within the cell
          (not valid for string data).

          * STANDARD_DEVIATION-The standard deviation of attributes of all the
          points within the cell. If there are less than two points in the cell,
          the cell is assigned NoData (not valid for string data).

          * MAXIMUM-The maximum value of the attributes of the points within the
          cell (not valid for string data).

          * MINIMUM-The minimum value of the attributes of the points within the
          cell (not valid for string data).

          * RANGE-The range of the attributes of the points within the cell (not
          valid for string data).

          * COUNT-The number of points within the cell.
      priority_field {Field}:
          This field is used when a feature should take preference over another
          feature with the same attribute.Priority field is only used with the
          Most frequent cell assignment
          type option.
      cellsize {Analysis Cell Size}:
          The cell size for the output raster dataset.The default cell size is
          the shortest of the width or height of the
          extent of the input feature dataset, in the output spatial reference,
          divided by 250.

     OUTPUTS:
      out_rasterdataset (Raster Dataset):
          The output raster dataset to be created.When not saving to a
          geodatabase, specify .tif for a TIFF file format,
          .img for an ERDAS IMAGINE file format, or no extension for an Esri
          Grid raster format."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.PointToRaster_conversion(*gp_fixargs((in_features, value_field, out_rasterdataset, cell_assignment, priority_field, cellsize), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('PolygonToRaster_conversion', None)
def PolygonToRaster(in_features=None, value_field=None, out_rasterdataset=None, cell_assignment=None, priority_field=None, cellsize=None):
    """PolygonToRaster_conversion(in_features, value_field, out_rasterdataset, {cell_assignment}, {priority_field}, {cellsize})

        Converts polygon features to a raster dataset.

     INPUTS:
      in_features (Feature Layer):
          The polygon input feature dataset to be converted to a raster.
      value_field (Field):
          The field used to assign values to the output raster.It can be any
          field of the input feature dataset's attribute table.
      cell_assignment {String}:
          The method to determine how the cell will be assigned a value when
          more than one feature falls within a cell.

          * CELL_CENTER-The polygon that overlaps the center of the cell yields
          the attribute to assign to the cell.

          * MAXIMUM_AREA-The single feature with the largest area within the
          cell yields the attribute to assign to the cell.

          * MAXIMUM_COMBINED_AREA-If there is more than one feature in a cell
          with the same value, the areas of these features will be combined. The
          combined feature with the largest area within the cell will determine
          the value to assign to the cell.
      priority_field {Field}:
          This field is used to determine which feature should take preference
          over another feature that falls over a cell. When it is used, the
          feature with the largest positive priority is always selected for
          conversion irrespective of the Cell assignment type chosen.
      cellsize {Analysis Cell Size}:
          The cell size for the output raster dataset.The default cell size is
          the shortest of the width or height of the
          extent of the input feature dataset, in the output spatial reference,
          divided by 250.

     OUTPUTS:
      out_rasterdataset (Raster Dataset):
          The output raster dataset to be created.When not saving to a
          geodatabase, specify .tif for a TIFF file format,
          .img for an ERDAS IMAGINE file format, or no extension for an Esri
          Grid raster format."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.PolygonToRaster_conversion(*gp_fixargs((in_features, value_field, out_rasterdataset, cell_assignment, priority_field, cellsize), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('PolylineToRaster_conversion', None)
def PolylineToRaster(in_features=None, value_field=None, out_rasterdataset=None, cell_assignment=None, priority_field=None, cellsize=None):
    """PolylineToRaster_conversion(in_features, value_field, out_rasterdataset, {cell_assignment}, {priority_field}, {cellsize})

        Converts polyline features to a raster dataset.

     INPUTS:
      in_features (Feature Layer):
          The polyline input feature dataset to be converted to a raster.
      value_field (Field):
          The field used to assign values to the output raster.It can be any
          field of the input feature dataset's attribute table.
      cell_assignment {String}:
          The method to determine how the cell will be assigned a value when
          more than one feature falls within a cell.

          * MAXIMUM_LENGTH-The feature with the longest length that covers the
          cell will determine the value to assign to the cell.

          * MAXIMUM_COMBINED_LENGTH-If there is more than one feature in a cell
          with the same value, the lengths of these features will be combined.
          The combined feature with the longest length within the cell will
          determine the value to assign to the cell.
      priority_field {Field}:
          This field is used to determine which feature should take preference
          over another feature that falls over a cell. When it is used, the
          feature with the largest positive priority is always selected for
          conversion irrespective of the Cell assignment type chosen.
      cellsize {Analysis Cell Size}:
          The cell size for the output raster dataset.The default cell size is
          the shortest of the width or height of the
          extent of the input feature dataset, in the output spatial reference,
          divided by 250.

     OUTPUTS:
      out_rasterdataset (Raster Dataset):
          The output raster dataset to be created.When not saving to a
          geodatabase, specify .tif for a TIFF file format,
          .img for an ERDAS IMAGINE file format, or no extension for an Esri
          Grid raster format."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.PolylineToRaster_conversion(*gp_fixargs((in_features, value_field, out_rasterdataset, cell_assignment, priority_field, cellsize), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('RasterToOtherFormat_conversion', None)
def RasterToOtherFormat(Input_Rasters=None, Output_Workspace=None, Raster_Format=None):
    """RasterToOtherFormat_conversion(Input_Rasters;Input_Rasters..., Output_Workspace, {Raster_Format})

        Converts one or more raster datasets to a different format.

     INPUTS:
      Input_Rasters (Raster Dataset):
          The raster datasets to convert.
      Output_Workspace (Workspace):
          The folder where the raster dataset will be written.
      Raster_Format {String}:
          The format of the new raster dataset.

          * BIL-Esri Band Interleaved by Line file

          * BIP-Esri Band Interleaved by Pixel file

          * BMP-Microsoft bitmap graphic raster dataset format

          * BSQ-Esri Band Sequential file

          * CRF-Cloud Raster Format

          * ENVI DAT-ENVI DAT file

          * GIF-Graphic Interchange Format for raster datasets

          * GRID-Esri Grid raster dataset format

          * IMAGINE Image-ERDAS IMAGINE raster data format

          * JP2000-JPEG 2000 raster dataset format

          * JPEG-Joint Photographic Experts Group raster dataset format

          * MRF-Meta Raster Format

          * PNG-Portable Network Graphic raster dataset format

          * TIFF-Tagged Image File Format for raster datasets"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RasterToOtherFormat_conversion(*gp_fixargs((Input_Rasters, Output_Workspace, Raster_Format), True)))
        return retval
    except Exception as e:
        raise e


# To Shapefile toolset
@gptooldoc('FeatureClassToShapefile_conversion', None)
def FeatureClassToShapefile(Input_Features=None, Output_Folder=None):
    """FeatureClassToShapefile_conversion(Input_Features;Input_Features..., Output_Folder)

        Copies the features from one or more feature classes or layers to a
        folder of shapefiles.

     INPUTS:
      Input_Features (Feature Layer):
          The list of input feature classes or feature layers that will be
          converted and added to the output folder.
      Output_Folder (Folder):
          The folder where the shapefiles will be written."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FeatureClassToShapefile_conversion(*gp_fixargs((Input_Features, Output_Folder), True)))
        return retval
    except Exception as e:
        raise e


# To dBASE toolset
@gptooldoc('TableToDBASE_conversion', None)
def TableToDBASE(Input_Table=None, Output_Folder=None):
    """TableToDBASE_conversion(Input_Table;Input_Table..., Output_Folder)

        Converts one or more tables to dBASE tables.

     INPUTS:
      Input_Table (Table View):
          The list of tables to be converted to dBASE.
      Output_Folder (Folder):
          The destination folder where the output dBASE tables will be placed."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.TableToDBASE_conversion(*gp_fixargs((Input_Table, Output_Folder), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject, gptoolnotsupported