#COPYRIGHT 2014 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
"""With Geostatistical Analyst, you can easily create a continuous surface, or map, from measured sample points stored in a point feature layer, raster layer, or by using polygon centroids. The sample points may be measurements such as elevation, depth to the water table, or levels of pollution. When used in conjunction with ArcMap, Geostatistical Analyst provides a comprehensive set of tools for creating surfaces that can be used to visualize, analyze, and understand spatial phenomena. Geostatistical Analyst contains tools for exploratory spatial data analysis and a geostatistical wizard to lead you through the process of creating a statistically valid surface."""
__all__ = ['GALayerToGrid', 'GACalculateZValue', 'GAGetModelParameter', 'GASetModelParameter', 'GANeighborhoodSelection', 'GAMovingWindowKriging', 'GASemivariogramSensitivity', 'GACreateGeostatisticalLayer', 'GALayerToContour', 'GALayerToPoints', 'GaussianGeostatisticalSimulations', 'SubsetFeatures', 'IDW', 'LocalPolynomialInterpolation', 'GlobalPolynomialInterpolation', 'CrossValidation', 'KernelInterpolationWithBarriers', 'DiffusionInterpolationWithBarriers', 'RadialBasisFunctions', 'CreateSpatiallyBalancedPoints', 'DensifySamplingNetwork', 'ExtractValuesToTable']
__alias__ = 'ga'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs, gptoolnotsupported
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
import _ga
from _ga import *
__all__ += _ga.__all__

# Interpolation toolset
@gptoolnotsupported
@gptooldoc('DiffusionInterpolationWithBarriers_ga', None)
def DiffusionInterpolationWithBarriers(in_features=None, z_field=None, out_layer=None, out_raster=None, cell_size=None, in_barrier_features=None, in_additive_barrier_raster=None, in_cumulative_barrier_raster=None, in_flow_barrier_raster=None, bandwidth=None, number_iterations=None, weight_field=None):
    """DiffusionInterpolationWithBarriers_ga(in_features, z_field, {out_layer}, {out_raster}, {cell_size}, {in_barrier_features}, {in_additive_barrier_raster}, {in_cumulative_barrier_raster}, {in_flow_barrier_raster}, {bandwidth}, {number_iterations}, {weight_field})

      INPUTS:
      in_features (Point|Multipoint|Polygon): The input point features containing the z-values to be interpolated.
      z_field (Short|Long|Float|Double): Field that holds a height or magnitude value for each point. This can be a numeric field or the Shape field if the input features contains z-values or m-values.
      cell_size {Analysis cell size}: The cell size at which the output raster will be created. 
                        This will be the value in the environment if it is explicitly set. Otherwise, it is the shorter of the width or the height of the extent of the input point features, in the input spatial reference, divided by 250.
      in_barrier_features {Polygon|Polyline}: The input absolute barrier feature class. Non Euclidean distances are used rather than "line of sight" distances.
      in_additive_barrier_raster {Raster Layer}: The travel distance from one raster cell to the next cell based on the following formula:
                        (average cost value in the neighboring cells) x (distance between cell centers)
      in_cumulative_barrier_raster {Raster Layer}: The travel distance from one raster cell to the next cell based on the following formula:
                         (difference between cost values in the neighboring cells) + (distance between cell centers)
      in_flow_barrier_raster {Raster Layer}: This barrier is use to interpolating data with preferential direction of data variation. It uses the following formula:
                        Indicator (cost values in the to neighboring cell > cost values in the from neighboring cell) * (cost values in the to neighboring cell - cost values in the from neighboring cell) + (distance between cell centers), 
                        where indicator(true) = 1 and indicator(false) = 0.
      bandwidth {0.0|1.79769313486e+308}: An argument of the kernel function that specifies the maximum distance at which data points are used for prediction. Prediction bias increases and prediction variance decreases with bandwidth increase.
      number_iterations {10.0|1000.0}: The model solves the diffusion equation numerically and this parameter controls the accuracy of the numerical solution. The larger the number, the more accurate the predictions and the longer the processing time will be. Also, the more complex the barriers geometry and the larger the bandwidth, the more iterations will be required for a accurate predictions.
      weight_field {Short|Long|Float|Double}: The larger the weight, the more impact it will have on the prediction. In the case of coincident observations, assign the largest weight to the most reliable measurement.

      OUTPUTS:
      out_layer {Geostatistical Layer}: Output geostatistical layer. This layer is a required output only if no output raster is requested.
      out_raster {Raster Dataset}: The output raster. This raster is a required output only if no output geostatistical layer is requested."""
    try:
        retval = convertArcObjectToPythonObject(gp.DiffusionInterpolationWithBarriers_ga(*gp_fixargs((in_features, z_field, out_layer, out_raster, cell_size, in_barrier_features, in_additive_barrier_raster, in_cumulative_barrier_raster, in_flow_barrier_raster, bandwidth, number_iterations, weight_field), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('GAMovingWindowKriging_ga', None)
def GAMovingWindowKriging(in_ga_model_source=None, in_datasets=None, in_locations=None, neighbors_max=None, out_featureclass=None, cell_size=None, out_surface_grid=None):
    """GAMovingWindowKriging_ga(in_ga_model_source, in_datasets;in_datasets..., in_locations, neighbors_max, out_featureclass, {cell_size}, {out_surface_grid})

      INPUTS:
      in_ga_model_source (Geostatistical Layer or File): Input geostatistical model source.
      in_datasets (Geostatistical Value Table): The name of the new input dataset and field name to use in the creation of the new layer.
      in_locations (Point): The locations of the points where the predictions or validations will be performed.
      neighbors_max (10.0|2147490647.0): Number of neighbors to use in the moving window.
      cell_size {Analysis cell size}: The cell size at which the output raster will be created.

      OUTPUTS:
      out_featureclass (Feature Class): The name of the output featureclass.
      out_surface_grid {Raster Dataset}: The ArcInfo GRID to be created.
                        The Prediction values in the output feature class are interpolated using the"""
    try:
        retval = convertArcObjectToPythonObject(gp.GAMovingWindowKriging_ga(*gp_fixargs((in_ga_model_source, in_datasets, in_locations, neighbors_max, out_featureclass, cell_size, out_surface_grid), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('GlobalPolynomialInterpolation_ga', None)
def GlobalPolynomialInterpolation(in_features=None, z_field=None, out_layer=None, out_raster=None, cell_size=None, power=None, weight_field=None):
    """GlobalPolynomialInterpolation_ga(in_features, z_field, {out_layer}, {out_raster}, {cell_size}, {power}, {weight_field})

      INPUTS:
      in_features (Point|Multipoint|Polygon): The input features containing the z-values to be interpolated.
      z_field (Short|Long|Float|Double): Field that holds a height or magnitude value for each point. This can be a numeric field or the Shape field if the input features contains z-values or m-values.
      cell_size {Analysis cell size}: The cell size at which the output raster will be created. 
                        This will be the value in the environment if it is explicitly set. Otherwise, it is the shorter of the width or the height of the extent of the input point features, in the input spatial reference, divided by 250.
      power {0.0|10.0}: The Power is the order of the polynomial (constant, 1st, 2nd, or 3rd).
      weight_field {Short|Long|Float|Double}: Field that holds the weight value for each point.

      OUTPUTS:
      out_layer {Geostatistical Layer}: Output geostatistical layer. This layer is a required output only if no output raster is requested.
      out_raster {Raster Dataset}: The output raster. This raster is a required output only if no output geostatistical layer is requested."""
    try:
        retval = convertArcObjectToPythonObject(gp.GlobalPolynomialInterpolation_ga(*gp_fixargs((in_features, z_field, out_layer, out_raster, cell_size, power, weight_field), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('IDW_ga', None)
def IDW(in_features=None, z_field=None, out_layer=None, out_raster=None, cell_size=None, power=None, search_neighborhood=None, weight_field=None):
    """IDW_ga(in_features, z_field, {out_layer}, {out_raster}, {cell_size}, {power}, {search_neighborhood}, {weight_field})

      INPUTS:
      in_features (Point|Multipoint|Polygon): The input point features containing the z-values to be interpolated.
      z_field (Short|Long|Float|Double): Field that holds a height or magnitude value for each point. This can be a numeric field or the Shape field if the input features contains z-values or m-values.
      cell_size {Analysis cell size}: The cell size at which the output raster will be created. 
                        This will be the value in the environment if it is explicitly set. Otherwise, it is the shorter of the width or the height of the extent of the input point features, in the input spatial reference, divided by 250.
      power {1.0|100.0}: The exponent of distance.
                        Controls the significance of surrounding points on the interpolated value. A higher power results in less influence from distant points.
      search_neighborhood {Geostatistical Search Neighborhood}: Defines which surrounding points will be used to control the output. There are two options: STANDARD and SMOOTH. Standard is the default.
                        STANDARD Major semiaxis  The major semi-axis value of the searching neighborhood.Minor semiaxis  The minor semi-axis value of the searching neighborhood.Angle  The angle of rotation for the axis (circle) or semi-major axis (ellipse) of the moving window.Maximum neighbors  The maximum number of neighbors that will be used to estimate the value at the unknown location.Minimum neighbors  The minimum number of neighbors that will be used to estimate the value at the unknown location.Sector type  The geometry of the neighborhood. One sector - Single ellipseFour sectors - Ellipse divided in four sectors.Four sectors shifted - Ellipse divided in four sectors and shifted 45 degrees.Eight sectors - Ellipse divided into eight sectors.
                        SMOOTH Major semiaxis  The major semi-axis value of the searching neighborhood.Minor semiaxis  The minor semi-axis value of the searching neighborhood.Angle  The angle of rotation for the axis (circle) or semi-major axis (ellipse) of the moving window.Smoothing factor  The Smooth Interpolation option creates an outer ellipse and an inner ellipse at a distance equal to the Major Semiaxis multiplied by the Smoothing factor. The points that fall outside the smaller ellipse but inside the largest ellipse are weighted using a sigmoidal function with a value between zero and one.
      weight_field {Short|Long|Float|Double}: Field that holds the weight value for each point.

      OUTPUTS:
      out_layer {Geostatistical Layer}: Output geostatistical layer. This layer is a required output only if no output raster is requested.
      out_raster {Raster Dataset}: The output raster. This raster is a required output only if no output geostatistical layer is requested."""
    try:
        retval = convertArcObjectToPythonObject(gp.IDW_ga(*gp_fixargs((in_features, z_field, out_layer, out_raster, cell_size, power, search_neighborhood, weight_field), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('KernelInterpolationWithBarriers_ga', None)
def KernelInterpolationWithBarriers(in_features=None, z_field=None, out_layer=None, out_raster=None, cell_size=None, in_barrier_features=None, kernel_function=None, bandwidth=None, power=None, ridge=None):
    """KernelInterpolationWithBarriers_ga(in_features, z_field, {out_layer}, {out_raster}, {cell_size}, {in_barrier_features}, {QUARTIC|EXPONENTIAL|GAUSSIAN|EPANECHNIKOV|POLYNOMIAL5|INVERSE_DISTANCE_WEIGHTING|CONSTANT}, {bandwidth}, {power}, {ridge})

      INPUTS:
      in_features (Point|Multipoint|Polygon): The input point features containing the z-values to be interpolated.
      z_field (Short|Long|Float|Double): Field that holds a height or magnitude value for each point. This can be a numeric field or the Shape field if the input features contains z-values or m-values.
      cell_size {Analysis cell size}: The cell size at which the output raster will be created. 
                        This will be the value in the environment if it is explicitly set. Otherwise, it is the shorter of the width or the height of the extent of the input point features, in the input spatial reference, divided by 250.
      in_barrier_features {Polygon|Polyline}: The input absolute barrier feature class. Non Euclidean distances are used rather than "line of sight" distances.
      kernel_function {String}: The kernel function.

                          *  QUARTIC
                         
                          *  EXPONENTIAL
                         
                          * GAUSSIAN
                         
                          *  EPANECHNIKOV
                         
                          *  POLYNOMIAL5
                         
                          *  INVERSE_DISTANCE_WEIGHTING
                         
                          *  CONSTANT
      bandwidth {0.0|1.79769313486e+308}: An argument of the kernel function that specifies the maximum distance at which data points are used for prediction. Prediction bias increases and prediction variance decreases with bandwidth increase.
      power {0.0|1.0}: Order of the polynomial
      ridge {1.0|100.0}: Is used for the numerical stabilization of the solution of the system of linear equations. It does not influence predictions in the case of regularly distributed data without barriers. Predictions for areas in which the data are located near the feature barrier or isolated by the barriers can be unstable and may require relatively large ridge parameter values.

      OUTPUTS:
      out_layer {Geostatistical Layer}: Output geostatistical layer. This layer is a required output only if no output raster is requested.
      out_raster {Raster Dataset}: The output raster. This raster is a required output only if no output geostatistical layer is requested."""
    try:
        retval = convertArcObjectToPythonObject(gp.KernelInterpolationWithBarriers_ga(*gp_fixargs((in_features, z_field, out_layer, out_raster, cell_size, in_barrier_features, kernel_function, bandwidth, power, ridge), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('LocalPolynomialInterpolation_ga', None)
def LocalPolynomialInterpolation(in_features=None, z_field=None, out_layer=None, out_raster=None, cell_size=None, power=None, search_neighborhood=None, kernel_function=None, bandwidth=None, condition_number=None, weight_field=None, output_type=None):
    """LocalPolynomialInterpolation_ga(in_features, z_field, {out_layer}, {out_raster}, {cell_size}, {power}, {search_neighborhood}, {QUARTIC|EXPONENTIAL|GAUSSIAN|EPANECHNIKOV|POLYNOMIAL5|INVERSE_DISTANCE_WEIGHTING|CONSTANT}, {bandwidth}, {condition_number}, {weight_field}, {PREDICTION|PREDICTION_STANDARD_ERROR|CONDITION_NUMBER})

      INPUTS:
      in_features (Point|Multipoint|Polygon): The input point features containing the z-values to be interpolated.
      z_field (Short|Long|Float|Double): Field that holds a height or magnitude value for each point. This can be a numeric field or the Shape field if the input features contains z-values or m-values.
      cell_size {Analysis cell size}: The cell size at which the output raster will be created. 
                        This will be the value in the environment if it is explicitly set. Otherwise, it is the shorter of the width or the height of the extent of the input point features, in the input spatial reference, divided by 250.
      power {0.0|3.0}: The order of the polynomial (constant, 1st, 2nd, or 3rd).
      search_neighborhood {Geostatistical Search Neighborhood}: Defines which surrounding points will be used to control the output. There are two options: STANDARD and SMOOTH. Standard is the default.
                        STANDARD Major semiaxis  The major semi-axis value of the searching neighborhood.Minor semiaxis  The minor semi-axis value of the searching neighborhood.Angle  The angle of rotation for the axis (circle) or semi-major axis (ellipse) of the moving window.Maximum neighbors  The maximum number of neighbors that will be used to estimate the value at the unknown location.Minimum neighbors  The minimum number of neighbors that will be used to estimate the value at the unknown location.Sector type  The geometry of the neighborhood. One sector - Single ellipseFour sectors - Ellipse divided in four sectors.Four sectors shifted - Ellipse divided in four sectors and shifted 45 degrees.Eight sectors - Ellipse divided into eight sectors.
                        SMOOTH Major semiaxis  The major semi-axis value of the searching neighborhood.Minor semiaxis  The minor semi-axis value of the searching neighborhood.Angle  The angle of rotation for the axis (circle) or semi-major axis (ellipse) of the moving window.Smoothing factor  The Smooth Interpolation option creates an outer ellipse and an inner ellipse at a distance equal to the Major Semiaxis multiplied by the Smoothing factor. The points that fall outside the smaller ellipse but inside the largest ellipse are weighted using a sigmoidal function with a value between zero and one.
      kernel_function {String}: The kernel function.

                          *  QUARTIC
                         
                          *  EXPONENTIAL
                         
                          * GAUSSIAN
                         
                          *  EPANECHNIKOV
                         
                          *  POLYNOMIAL5
                         
                          *  INVERSE_DISTANCE_WEIGHTING
                         
                          *  CONSTANT
      bandwidth {0.0|1.79769313486e+308}: An argument of the kernel function that specifies the maximum distance at which data points are used for prediction. Prediction bias increases and prediction variance decreases with bandwidth increase.
      condition_number {1.0|1.79769313486e+308}: Every invertible square matrix has a condition number that indicates how inaccurate the solution to the linear equations can be with a small change in the matrix coefficients (it can be due to imprecise data) . If the condition number is large, a small change in the matrix coefficients results in a large change in the solution vector .
      weight_field {Short|Long|Float|Double}: The larger the weight, the more impact it will have on the prediction. In the case of coincident observations, assign the largest weight to the most reliable measurement.
      output_type {String}: The type of output .

                          *  PREDICTIONPredicition surfaces are produced from the interpolated values.
                         
                          *  PREDICTION_STANDARD_ERROR Standard Error surfaces are produced from the standard errors of the interpolated values.
                         
                          * CONDITION_NUMBERThe Spatial condition number surface indicates variation in the numerical model stability and provides additional information on the prediction uncertainty as the prediction standard error surface is created assuming that the model is correct, which implies that there is no reason for model instability.

      OUTPUTS:
      out_layer {Geostatistical Layer}: Output geostatistical layer. This layer is a required output only if no output raster is requested.
      out_raster {Raster Dataset}: The output raster. This raster is a required output only if no output geostatistical layer is requested."""
    try:
        retval = convertArcObjectToPythonObject(gp.LocalPolynomialInterpolation_ga(*gp_fixargs((in_features, z_field, out_layer, out_raster, cell_size, power, search_neighborhood, kernel_function, bandwidth, condition_number, weight_field, output_type), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('RadialBasisFunctions_ga', None)
def RadialBasisFunctions(in_features=None, z_field=None, out_layer=None, out_raster=None, cell_size=None, search_neighborhood=None, radial_basis_functions=None, small_scale_parameter=None):
    """RadialBasisFunctions_ga(in_features, z_field, {out_layer}, {out_raster}, {cell_size}, {search_neighborhood}, {THIN_PLATE_SPLINE|COMPLETELY_REGULARIZED_SPLINE|SPLINE_WITH_TENSION|MULTIQUADRIC_FUNCTION|INVERSE_MULTIQUADRIC_FUNCTION}, {small_scale_parameter})

      INPUTS:
      in_features (Point|Multipoint|Polygon): The input features containing the z-values to be interpolated.
      z_field (Short|Long|Float|Double): The cell size at which the output raster will be created. 
                        This will be the value in the environment if it is explicitly set. Otherwise, it is the shorter of the width or the height of the extent of the input point features, in the input spatial reference, divided by 250.
      cell_size {Analysis cell size}: The cell size at which the output raster will be created. 
                        This will be the value in the environment if it is explicitly set. Otherwise, it is the shorter of the width or the height of the extent of the input point features, in the input spatial reference, divided by 250.
      search_neighborhood {Geostatistical Search Neighborhood}: Defines which surrounding points will be used to control the output. There are two options: STANDARD and SMOOTH. Standard is the default.
                        STANDARD Major semiaxis  The major semi-axis value of the searching neighborhood.Minor semiaxis  The minor semi-axis value of the searching neighborhood.Angle  The angle of rotation for the axis (circle) or semi-major axis (ellipse) of the moving window.Maximum neighbors  The maximum number of neighbors that will be used to estimate the value at the unknown location.Minimum neighbors  The minimum number of neighbors that will be used to estimate the value at the unknown location.Sector type  The geometry of the neighborhood. One sector - Single ellipseFour sectors - Ellipse divided in four sectors.Four sectors shifted - Ellipse divided in four sectors and shifted 45 degrees.Eight sectors - Ellipse divided into eight sectors.
                        SMOOTH Major semiaxis  The major semi-axis value of the searching neighborhood.Minor semiaxis  The minor semi-axis value of the searching neighborhood.Angle  The angle of rotation for the axis (circle) or semi-major axis (ellipse) of the moving window.Smoothing factor  The Smooth Interpolation option creates an outer ellipse and an inner ellipse at a distance equal to the Major Semiaxis multiplied by the Smoothing factor. The points that fall outside the smaller ellipse but inside the largest ellipse are weighted using a sigmoidal function with a value between zero and one.
      radial_basis_functions {String}: Radial Basis Functions.

                          *  THIN_PLATE_SPLINE Thin-plate spline 
                         
                          *  SPLINE_WITH_TENSION  Spline with tension
                         
                          * COMPLETELY_REGULARIZED_SPLINE  Completely regularized spline
                         
                          * MULTIQUADRIC_FUNCTION  Multiquadric function
                         
                          * INVERSE_MULTIQUADRIC_ FUNCTION Inverse multiquadric function
      small_scale_parameter {2.22507392851e-308|1.79769313486e+308}: The small scale parameter is used to calculate the weights assigned to the points located in the moving window. Each of the radial basis functions has a parameter that controls the degree of small-scale variation of the surface. The (optimal) parameter is determined by finding the value that minimizes the root mean square prediction error (RMSPE).

      OUTPUTS:
      out_layer {Geostatistical Layer}: Output geostatistical layer. This layer is a required output only if no output raster is requested.
      out_raster {Raster Dataset}: The output raster. This raster is a required output only if no output geostatistical layer is requested."""
    try:
        retval = convertArcObjectToPythonObject(gp.RadialBasisFunctions_ga(*gp_fixargs((in_features, z_field, out_layer, out_raster, cell_size, search_neighborhood, radial_basis_functions, small_scale_parameter), True)))
        return retval
    except Exception as e:
        raise e


# Sampling Network Design toolset
@gptoolnotsupported
@gptooldoc('CreateSpatiallyBalancedPoints_ga', None)
def CreateSpatiallyBalancedPoints(in_probability_raster=None, out_feature_class=None, number_output_points=None):
    """CreateSpatiallyBalancedPoints_ga(in_probability_raster, out_feature_class, number_output_points)

      INPUTS:
      in_probability_raster (Raster Layer): This raster defines the inclusion probabilities for each location in the area of interest.
      number_output_points (1.0|2147490647.0): This parameter defines how many sample locations will be generated.

      OUTPUTS:
      out_feature_class (Feature Class): The output feature class will contain the selected sample locations and their inclusion probabilities."""
    try:
        retval = convertArcObjectToPythonObject(gp.CreateSpatiallyBalancedPoints_ga(*gp_fixargs((in_probability_raster, out_feature_class, number_output_points), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('DensifySamplingNetwork_ga', None)
def DensifySamplingNetwork(in_geostat_layer=None, out_feature_class=None, number_output_points=None, selection_criteria=None, threshold=None, in_weight_raster=None, in_candidate_point_features=None, inhibition_distance=None):
    """DensifySamplingNetwork_ga(in_geostat_layer, out_feature_class, number_output_points, {STDERR|STDERR_THRESHOLD|QUARTILE_THRESHOLD}, {threshold}, {in_weight_raster}, {in_candidate_point_features}, {inhibition_distance})

      INPUTS:
      in_geostat_layer (Geostatistical Layer): Input a geostatistical layer resulting from a Kriging model.
      number_output_points (1.0|2147490647.0): This parameter defines how many sample locations will be generated.
      selection_criteria {String}: Methods that are available to densify the network.
                        See usage tip.
      threshold {2.22507392851e-308|1.79769313486e+308}: The threshold value if STDERR_THRESHOLD or QUARTILE_THRESHOLD selection criteria are used.
      in_weight_raster {Raster Layer}: Weight raster from which to determine which locations should have preferance.
      in_candidate_point_features {Point}: The location the sample locations to pick from.
      inhibition_distance {Linear unit}: Do not place any samples within this distance from each other.

      OUTPUTS:
      out_feature_class (Feature Class): The name of the output feature class."""
    try:
        retval = convertArcObjectToPythonObject(gp.DensifySamplingNetwork_ga(*gp_fixargs((in_geostat_layer, out_feature_class, number_output_points, selection_criteria, threshold, in_weight_raster, in_candidate_point_features, inhibition_distance), True)))
        return retval
    except Exception as e:
        raise e


# Simulation toolset
@gptoolnotsupported
@gptooldoc('ExtractValuesToTable_ga', None)
def ExtractValuesToTable(in_features=None, in_rasters=None, out_table=None, out_table_raster_names=None, add_warning_field=None):
    """ExtractValuesToTable_ga(in_features, in_rasters;in_rasters..., out_table, {out_table_raster_names}, {add_warning_field})

      INPUTS:
      in_features (Point|Polygon): The input feature class containing points or polygons.
      in_rasters (Raster Layer): A list of input rasters. These must all have the same extent, coordinate system and cell size.
                        A list of input rasters.
      add_warning_field {Boolean}: Specifies whether or not the warning field in the output table will be populated.

                          * TRUE field, in the output table, with flags describing whether or not the feature is completely or partially covered by the input raster. 


                          * FALSE field will not be added to the output table.

      OUTPUTS:
      out_table (Table): Output table.
      out_table_raster_names {Table}: Table listing the input rasters."""
    try:
        retval = convertArcObjectToPythonObject(gp.ExtractValuesToTable_ga(*gp_fixargs((in_features, in_rasters, out_table, out_table_raster_names, add_warning_field), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('GaussianGeostatisticalSimulations_ga', None)
def GaussianGeostatisticalSimulations(in_geostat_layer=None, number_of_realizations=None, output_workspace=None, output_simulation_prefix=None, in_conditioning_features=None, conditioning_field=None, cell_size=None, in_bounding_dataset=None, save_simulated_rasters=None, quantile=None, threshold=None, in_stats_polygons=None, raster_stat_type=None, conditioning_measurement_error_field=None, out_workspace=None, out_polygon_stat=None, out_raster_simulation=None, out_raster_stat=None, out_convergence_value=None):
    """GaussianGeostatisticalSimulations_ga(in_geostat_layer, number_of_realizations, output_workspace, output_simulation_prefix, {in_conditioning_features}, {conditioning_field}, {cell_size}, {in_bounding_dataset}, {save_simulated_rasters}, {quantile}, {threshold}, {in_stats_polygons}, {None|MIN|MAX|MEAN|STDDEV|QUARTILE1|MEDIAN|QUARTILE3|QUANTILE|P_THRSHLD}, {conditioning_measurement_error_field})

      INPUTS:
      in_geostat_layer (Geostatistical Layer): Input a geostatistical layer resulting from a Simple Kriging model.
      number_of_realizations (1.0|4500.0): The number of realizations to perform.
      output_workspace (Workspace): The workspace for all the output results.
      output_simulation_prefix (String): 1- to 3-character alphanumeric prefix that will automatically be added to the output dataset names.
      in_conditioning_features {Point|Polygon}: The features that are used to condition the realizations. Leave this blank to produce unconditional realizations.
      conditioning_field {Short|Long|Float|Double}: The field used to condition the realizations. Leave this blank to produce unconditional realizations.
      cell_size {Analysis cell size}: A constant measurement error for all input data can be specified in the input semivariogram model. However, if the measurement error values are not the same at each sampling location, they can be specified using this field. The units are the same as those of the input measurements.
                        Leave this blank if there are no measurement error values.
      in_bounding_dataset {Polygon|Point}: The cell size at which the output raster will be created. 
                        This will be the value in the environment if it is explicitly set. Otherwise, it is the shorter of the width or the height of the extent of the input point features, in the input spatial reference, divided by 250.
      save_simulated_rasters {Boolean}: The feature outline to which the analysis is to be limited. If point features are entered, then a convex hull polygon will be created automatically and the realizations will be performed within that polygon.
      quantile {2.22044604925e-16|1.0}: The option of whether the simulated rasters be persisted (saved to disk).
      threshold {Double}: The quantile value (0 < Q < 1) for which the output raster will be generated.
      in_stats_polygons {Polygon}: The threshold value for which the output raster will be generated. The raster will be the percentage of the number of times that the particular threshold was exceeded, on a cell by cell basis.
                        The threshold value for which the output raster will be generated.
      raster_stat_type {String}: Input polygons representing areas of interest for the summary statistics to be calculated.
      conditioning_measurement_error_field {Short|Long|Float|Double}: The simulated rasters are post-processed on a cell by cell basis. Each of the selected statistics will be calculated and reported in an output raster.

                          * MIN Calculates the minimum (smallest value)
                         
                          * MAX Calculates the maximum (largest value)
                         
                          * MEAN Calculates the mean (average) 
                         
                          * STDDEV Calculates the standard deviation
                         
                          * QUARTILE1 Calculates the 25th quantile
                         
                          * MEDIAN Calculates the median
                         
                          * QUARTILE3 Calculates the 75th quantile 
                         
                          * QUANTILE Calculates a user specified quantile (0 < Q < 1) 
                         
                          * P_THRSHLD Calculates the percentage of the realizations where the cell value exceeds a user specified threshold value

      OUTPUTS:
      out_workspace {Workspace}: Output workspace
      out_polygon_stat {Feature Class}: Output statistical polygons
      out_raster_simulation {Raster Layer}: Output simulation rasters
      out_raster_stat {Raster Layer}: Output statistical rasters
      out_convergence_value {Double}: Convergence"""
    try:
        retval = convertArcObjectToPythonObject(gp.GaussianGeostatisticalSimulations_ga(*gp_fixargs((in_geostat_layer, number_of_realizations, output_workspace, output_simulation_prefix, in_conditioning_features, conditioning_field, cell_size, in_bounding_dataset, save_simulated_rasters, quantile, threshold, in_stats_polygons, raster_stat_type, conditioning_measurement_error_field, out_workspace, out_polygon_stat, out_raster_simulation, out_raster_stat, out_convergence_value), True)))
        return retval
    except Exception as e:
        raise e


# Utilities toolset
@gptoolnotsupported
@gptooldoc('CrossValidation_ga', None)
def CrossValidation(in_geostat_layer=None, out_feature_class=None, count=None, mean_error=None, root_mean_square=None, average_standard=None, mean_standardized=None, root_mean_square_standardized=None):
    """CrossValidation_ga(in_geostat_layer, {out_feature_class})

      INPUTS:
      in_geostat_layer (Geostatistical Layer): Input geostatistical layer.

      OUTPUTS:
      out_feature_class {Feature Class}: Cross validation statistics at each location.
      count {Long}: Count
      mean_error {Double}: Mean Error
      root_mean_square {Double}: Root Mean Square
      average_standard {Double}: Average Standard
      mean_standardized {Double}: Mean Standardized
      root_mean_square_standardized {Double}: Root Mean Square Standardized"""
    try:
        retval = convertArcObjectToPythonObject(gp.CrossValidation_ga(*gp_fixargs((in_geostat_layer, out_feature_class, count, mean_error, root_mean_square, average_standard, mean_standardized, root_mean_square_standardized), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('GANeighborhoodSelection_ga', None)
def GANeighborhoodSelection(in_dataset=None, out_layer=None, point_coord=None, neighbors_max=None, neighbors_min=None, minor_semiaxis=None, major_semiaxis=None, angle=None, shape_type=None):
    """GANeighborhoodSelection_ga(in_dataset, out_layer, point_coord, neighbors_max, neighbors_min, minor_semiaxis, major_semiaxis, angle, {One sector|Four sectors|Four sectors shifted|Eight sectors})

      INPUTS:
      in_dataset (Point): Points from which to create a neighborhood selection.
      point_coord (Point): The x,y coordinate of the center of the neighborhood.
      neighbors_max (1.0|2147490647.0): The number of points to use in each sector. Some sectors may not have the required number of points, in which case all points in that sector will be used.
      neighbors_min (1.0|2147490647.0): The minimum number of points to use in each sector. If the minimum number of required points are not available in any given sector, the nearest available point(s) outside the sector will be selected.
      minor_semiaxis (2.22507392851e-308|1.79769313486e+308): Size of the minor semi-axis of the search neighborhood.
      major_semiaxis (2.22507392851e-308|1.79769313486e+308): Size of the major semi-axis of the search neighborhood.
      angle (0.0|360.0): The angle of rotation of the axis of the neighborhood.
      shape_type {String}: The geometry of the neighborhood.

                          * One sector  Single ellipse. 
                         
                          * Four sectors  Ellipse divided in four sectors. 
                         
                          * Four sectors shifted  Ellipse divided in four sectors and shifted 45 degrees. 
                         
                          * Eight sectors  Ellipse divided into eight sectors.

      OUTPUTS:
      out_layer (Feature Layer): The name of the layer to contain the neighborhood selection."""
    try:
        retval = convertArcObjectToPythonObject(gp.GANeighborhoodSelection_ga(*gp_fixargs((in_dataset, out_layer, point_coord, neighbors_max, neighbors_min, minor_semiaxis, major_semiaxis, angle, shape_type), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('GASemivariogramSensitivity_ga', None)
def GASemivariogramSensitivity(in_ga_model_source=None, in_datasets=None, in_locations=None, nugget_span_percents=None, nugget_calc_times=None, partialsill_span_percents=None, partialsill_calc_times=None, range_span_percents=None, range_calc_times=None, minrange_span_percents=None, minrange_calc_times=None, out_table=None):
    """GASemivariogramSensitivity_ga(in_ga_model_source, in_datasets;in_datasets..., in_locations, {nugget_span_percents}, {nugget_calc_times}, {partialsill_span_percents}, {partialsill_calc_times}, {range_span_percents}, {range_calc_times}, {minrange_span_percents}, {minrange_calc_times}, out_table)

      INPUTS:
      in_ga_model_source (Geostatistical Layer or File): Input geostatistical model source.
      in_datasets (Geostatistical Value Table): This input has two sections: Dataset  The path and the name of the input data.Field  The name of the required field.
      in_locations (Point): The locations of the points where the analysis will be performed.
      nugget_span_percents {0.0|100.0}: The percentage that is subtracted and added to the Nugget parameter to create a range from which a random Nugget parameter will be selected.
      nugget_calc_times {0.0|2147490647.0}: The number of random Nugget parameters that will be drawn from the Nugget span.
      partialsill_span_percents {0.0|100.0}: The percentage that is subtracted and added to the Partial Sill parameter to create a range from which a random Partial Sill parameter will be selected.
      partialsill_calc_times {0.0|2147490647.0}: The number of random Partial Sill parameters that will be drawn from the Partial Sill span.
      range_span_percents {0.0|100.0}: The percentage that is subtracted and added to the Major Range parameter to create a range from which a random Major Range parameter will be selected.
      range_calc_times {0.0|2147490647.0}: The number of random Major Range parameters that will be drawn from the Major Range span.
      minrange_span_percents {0.0|100.0}: The percentage that is subtracted and added to the Minor Range parameter to create a range from which a random Minor Range parameter will be selected.
      minrange_calc_times {0.0|2147490647.0}: The number of random Minor Range parameters that will be drawn from the Minor Range span.

      OUTPUTS:
      out_table (Table): Table of sensitivity results."""
    try:
        retval = convertArcObjectToPythonObject(gp.GASemivariogramSensitivity_ga(*gp_fixargs((in_ga_model_source, in_datasets, in_locations, nugget_span_percents, nugget_calc_times, partialsill_span_percents, partialsill_calc_times, range_span_percents, range_calc_times, minrange_span_percents, minrange_calc_times, out_table), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('SubsetFeatures_ga', None)
def SubsetFeatures(in_features=None, out_training_features=None, out_test_features=None, size_of_training_dataset=None, subset_size_units=None):
    """SubsetFeatures_ga(in_features, out_training_features, {out_test_features}, {size_of_training_dataset}, {PERCENTAGE_OF_INPUT|ABSOLUTE_VALUE})

      INPUTS:
      in_features (Table View): The input feature class containing points, lines, or polygons.
      size_of_training_dataset {2.22507392851e-308|100.0}: The size of the output training feature class. This value can be expressed either as a percentage of the input features or as an absolute number of features.
      subset_size_units {Boolean}: Keyword describing the subset size.

                          * Percentage of input the percentage of the input features that will be in the training dataset. 


                          * Absolute value the number of features that will be in the training dataset.

      OUTPUTS:
      out_training_features (Feature Class or Table): Output training features.
      out_test_features {Feature Class or Table}: Output test features."""
    try:
        retval = convertArcObjectToPythonObject(gp.SubsetFeatures_ga(*gp_fixargs((in_features, out_training_features, out_test_features, size_of_training_dataset, subset_size_units), True)))
        return retval
    except Exception as e:
        raise e


# Working with Geostatistical Layers toolset
@gptoolnotsupported
@gptooldoc('GACalculateZValue_ga', None)
def GACalculateZValue(in_geostat_layer=None, point_coord=None, out_z_value=None):
    """GACalculateZValue_ga(in_geostat_layer, point_coord)

      INPUTS:
      in_geostat_layer (Geostatistical Layer): Input geostatistical layer.
      point_coord (Point): The x,y coordinate of the point where the Z value is required.

      OUTPUTS:
      out_z_value {Double}: Result (z-value)"""
    try:
        retval = convertArcObjectToPythonObject(gp.GACalculateZValue_ga(*gp_fixargs((in_geostat_layer, point_coord, out_z_value), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('GACreateGeostatisticalLayer_ga', None)
def GACreateGeostatisticalLayer(in_ga_model_source=None, in_datasets=None, out_layer=None):
    """GACreateGeostatisticalLayer_ga(in_ga_model_source, in_datasets;in_datasets..., out_layer)

      INPUTS:
      in_ga_model_source (Geostatistical Layer or File): Input geostatistical model source.
      in_datasets (Geostatistical Value Table): The name of the new input dataset and field name to use in the creation of the new layer.

      OUTPUTS:
      out_layer (Geostatistical Layer): Output geostatistical layer."""
    try:
        retval = convertArcObjectToPythonObject(gp.GACreateGeostatisticalLayer_ga(*gp_fixargs((in_ga_model_source, in_datasets, out_layer), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('GAGetModelParameter_ga', None)
def GAGetModelParameter(in_ga_model_source=None, model_param_xpath=None, out_param_value=None):
    """GAGetModelParameter_ga(in_ga_model_source, model_param_xpath)

      INPUTS:
      in_ga_model_source (Geostatistical Layer or File): Input geostatistical model source.
      model_param_xpath (String): Xpath to the required model parameter.

      OUTPUTS:
      out_param_value {String}: Requested model parameter."""
    try:
        retval = convertArcObjectToPythonObject(gp.GAGetModelParameter_ga(*gp_fixargs((in_ga_model_source, model_param_xpath, out_param_value), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('GALayerToContour_ga', None)
def GALayerToContour(in_geostat_layer=None, contour_type=None, out_feature_class=None, contour_quality=None):
    """GALayerToContour_ga(in_geostat_layer, Contour|Filled contour, out_feature_class, {Draft|Presentation})

      INPUTS:
      in_geostat_layer (Geostatistical Layer): Input geostatistical layer.
      contour_type (String): Type of contour to represent the geostatistical layer by.

                          * Contour is the contour or isoline representation of the geostatistical layer. You can display the lines in either draft or presentation quality. 


                          * Filled contour is the polygon representation of the geostatistical layer. It is assumed for the graphical display that the values between each contour line are the same for all locations within the polygon. You can display the lines in either draft or presentation quality. 

                        Type of contour to represent the geostatistical layer by.

                          * Filled contour is the polygon representation of the geostatistical layer. It is assumed for the graphical display that the values between each contour line are the same for all locations within the polygon. You can display the lines in either draft or presentation quality.
      contour_quality {String}: The Quality options provide control over the smoothness of displayed Contours and Filled Contours.

                          * Draft The default Draft quality presents generalized version of isolines for faster display. 


                          * Presentation The Presentation option brings more detailed isolines to the output feature class.

      OUTPUTS:
      out_feature_class (Feature Class): The name of the output featureclass. It will be either polyline or polygon depending on the output contour type."""
    try:
        retval = convertArcObjectToPythonObject(gp.GALayerToContour_ga(*gp_fixargs((in_geostat_layer, contour_type, out_feature_class, contour_quality), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('GALayerToGrid_ga', None)
def GALayerToGrid(in_geostat_layer=None, out_surface_grid=None, cell_size=None, points_per_block_horz=None, points_per_block_vert=None):
    """GALayerToGrid_ga(in_geostat_layer, out_surface_grid, {cell_size}, {points_per_block_horz}, {points_per_block_vert})

      INPUTS:
      in_geostat_layer (Geostatistical Layer): Input geostatistical layer.
      cell_size {Analysis cell size}: The cell size at which the output raster will be created.
      points_per_block_horz {1.0|256.0}: The number of predictions for each cell in the horizontal direction for block interpolation.
      points_per_block_vert {1.0|256.0}: The number of predictions for each cell in the vertical direction for block interpolation.

      OUTPUTS:
      out_surface_grid (Raster Dataset): The raster to be created."""
    try:
        retval = convertArcObjectToPythonObject(gp.GALayerToGrid_ga(*gp_fixargs((in_geostat_layer, out_surface_grid, cell_size, points_per_block_horz, points_per_block_vert), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('GALayerToPoints_ga', None)
def GALayerToPoints(in_geostat_layer=None, in_locations=None, z_field=None, out_feature_class=None):
    """GALayerToPoints_ga(in_geostat_layer, in_locations, {z_field}, out_feature_class)

      INPUTS:
      in_geostat_layer (Geostatistical Layer): Input geostatistical layer.
      in_locations (Point): The locations of the points where the predictions or validations will be performed.
      z_field {Short|Long|Float|Double}: If this field is left blank, predictions will be made at the location points. If a field is selected, predictions will be made and compared to the values in the Z_value_field and a validation analysis is performed.

      OUTPUTS:
      out_feature_class (Feature Class): The name of the output feature class containing either the predictions or the predictions and the validation results."""
    try:
        retval = convertArcObjectToPythonObject(gp.GALayerToPoints_ga(*gp_fixargs((in_geostat_layer, in_locations, z_field, out_feature_class), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('GASetModelParameter_ga', None)
def GASetModelParameter(in_ga_model_source=None, model_param_xpath=None, in_param_value=None, out_ga_model=None):
    """GASetModelParameter_ga(in_ga_model_source, model_param_xpath, in_param_value, out_ga_model)

      INPUTS:
      in_ga_model_source (Geostatistical Layer or File): Input geostatistical model source.
      model_param_xpath (String): Xpath to the required model parameter.
      in_param_value (String): New parameter value for the parameter defined by the xpath.

      OUTPUTS:
      out_ga_model (xml): New model created with the parameter value defined in the xpath."""
    try:
        retval = convertArcObjectToPythonObject(gp.GASetModelParameter_ga(*gp_fixargs((in_ga_model_source, model_param_xpath, in_param_value, out_ga_model), True)))
        return retval
    except Exception as e:
        raise e

