# -*- coding: utf-8 -*-
#COPYRIGHT 2017 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""Topographic Production toolbox contains tools that are used in defense
topographic production."""
__all__ = ['CalculateDefaultValues', 'CalculateMetrics', 'ExportMetadata',
           'ExportTopology', 'GAIT', 'GeoNamesToGeodatabase',
           'GeodatabaseToShape', 'ImportMetadata', 'ImportTopology', 'LoadData',
           'SplitFeatures', 'UnzipCellAndImport', 'UpdateGeoNames']
__alias__ = 'topographic'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs, gptoolnotsupported
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Data Management\Features toolset
@gptoolnotsupported
@gptooldoc('CalculateDefaultValues_topographic', None)
def CalculateDefaultValues(in_datasets=None):
    """CalculateDefaultValues_topographic(in_datasets;in_datasets...)

        Replaces null values in a feature class or table with the default
        values from the geodatabase feature class.

     INPUTS:
      in_datasets (Table View / Feature Layer / Dataset):
          The feature classes and/or tables whose null values will be replaced
          with the default values from the data model."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CalculateDefaultValues_topographic(*gp_fixargs((in_datasets,), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('CalculateMetrics_topographic', None)
def CalculateMetrics(in_features=None, in_metric_types=None, in_length_attributes=None, in_width_attributes=None, in_area_attributes=None, in_angle_attributes=None, in_elevation_attributes=None, in_precision=None):
    """CalculateMetrics_topographic(in_features;in_features..., in_metric_types;in_metric_types..., {in_length_attributes}, {in_width_attributes}, {in_area_attributes}, {in_angle_attributes}, {in_elevation_attributes}, {in_precision})

        Populates metrics for features in Defense Mapping data models. Metrics
        include length, width, area, and elevation attributes.

     INPUTS:
      in_features (Feature Layer):
          Features on which metrics will be calculated.
      in_metric_types (String):
          Types of metrics to calculate include angle of orientation, area,
          elevation, length, and width.

          * ANGLE_OF_ORIENTATION-Calculates angle of orientation metrics

          * AREA-Calculates area metrics

          * ELEVATION-Calculates elevation metrics

          * LENGTH-Calculate length metrics

          * WIDTH-Calculate width metrics
      in_length_attributes {String}:
          A comma-delimited string of field names from which the length metrics
          will be calculated. The default is LEG,LEN,LEN_,LGN,LZN. You can add
          the names of other length metric fields; if the fields exist in Input
          Features, they will be computed.
      in_width_attributes {String}:
          A comma-delimited string of field names from which the width metrics
          will be calculated. The default is WID,WID_,WGP. You can add the names
          of other width metric fields; if the fields exist in Input Features,
          they will be computed.
      in_area_attributes {String}:
          A comma-delimited string of field names from which the area metrics
          will be calculated. The default is ARA,ARE,ARE_. You can add the names
          of other area metric fields; if the fields exist in Input Features,
          they will be computed.
      in_angle_attributes {String}:
          A comma-delimited string of field names from which the angle of
          orientation metrics will be calculated. The default is AOO,DOF,FEO.
          You can add the names of other angle of orientation metric fields; if
          the fields exist in Input Features, they will be computed.
      in_elevation_attributes {String}:
          A comma-delimited string of field names from which the elevation
          metrics will be calculated. The default is ZV2,ZVH. You can add the
          names of other elevation metric fields; if the fields exist in Input
          Features, they will be computed.
      in_precision {Long}:
          Precision of the metrics written to the target attributes."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CalculateMetrics_topographic(*gp_fixargs((in_features, in_metric_types, in_length_attributes, in_width_attributes, in_area_attributes, in_angle_attributes, in_elevation_attributes, in_precision), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('SplitFeatures_topographic', None)
def SplitFeatures(cutting_features=None, target_features=None, use_target_z=None):
    """SplitFeatures_topographic(cutting_features, target_features;target_features..., use_target_z)

        Splits features for any number of polyline or polygon target feature
        classes using the cutting features and inserts points on the cutting
        feature.

     INPUTS:
      cutting_features (Feature Layer):
          The source features used to split target features at intersection
          points of the feature class geometries.
      target_features (Feature Layer):
          The features that will be divided by the cutting features.
      use_target_z (Boolean):
          Determines the source of the z-value from the source or target.

          * USE_TARGET_Z-Uses the z-value from the source or target.

          * DONT_USE_TARGET_Z-Does not use the z-value. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SplitFeatures_topographic(*gp_fixargs((cutting_features, target_features, use_target_z), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('UpdateGeoNames_topographic', None)
def UpdateGeoNames(in_features=None, in_geonames_features=None, in_geonames_table=None, named_feature_id_field=None, name_id_field=None, name_field=None):
    """UpdateGeoNames_topographic(in_features;in_features..., in_geonames_features, in_geonames_table, named_feature_id_field, name_id_field, name_field)

        Updates the name field on input features based on the information from
        GeoNames_FeaturesP and GEONAMES_TABLE.

     INPUTS:
      in_features (Feature Layer):
          The input features that will be updated. Each in_features value should
          have field names matching the values specified for the
          named_feature_id_field, name_id_field, and name_field parameters.
      in_geonames_features (Feature Layer):
          The input GeoNames features that identify unique named feature
          locations.
      in_geonames_table (Table View):
          A table containing name records related to the input GeoNames
          features.
      named_feature_id_field (Field):
          The field storing GeoNames named feature identifier values. These
          values should not be null or empty on the input features.
      name_id_field (Field):
          The field to store GeoNames name identifier values.
      name_field (Field):
          The field to store GeoNames name values."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpdateGeoNames_topographic(*gp_fixargs((in_features, in_geonames_features, in_geonames_table, named_feature_id_field, name_id_field, name_field), True)))
        return retval
    except Exception as e:
        raise e


# Data Management\Geodatabase toolset
@gptoolnotsupported
@gptooldoc('ExportMetadata_topographic', None)
def ExportMetadata(in_cell_features=None, export_location=None):
    """ExportMetadata_topographic(in_cell_features, export_location)

        Exports the Multinational Geospatial Co-production Program (MGCP)
        metadata datasets (Cell, Subregion, and Source feature classes) to an
        XML file.

     INPUTS:
      in_cell_features (Feature Layer):
          The MGCP Cell feature layer to export.
      export_location (Folder):
          The directory where the metadata XML files will be created."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportMetadata_topographic(*gp_fixargs((in_cell_features, export_location), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('GeoNamesToGeodatabase_topographic', None)
def GeoNamesToGeodatabase(in_source=None, in_feature_class=None, in_allow_duplicates=None, in_table=None):
    """GeoNamesToGeodatabase_topographic(in_source, in_feature_class, in_allow_duplicates, in_table)

        Loads GeoNames data into a feature class and table. The feature class
        is composed of point features, and the table contains fields with
        information concerning the naming conventions used for the features.
        The feature class contains the Unique Feature Identifier (UFI) and
        Unique Name Identifier (UNI), which match the same fields in the
        GeoNames table.

     INPUTS:
      in_source (Text File / Shapefile):
          Path to the source file containing GeoNames information. This needs to
          be a properly formatted GeoNames file.
      in_feature_class (Feature Class):
          The GeoNames feature class; this feature class should be in the
          working database.
      in_allow_duplicates (Boolean):
          Allows duplicate features in the GeoNames feature class.

          * ALLOW_DUPLICATES-Allows the tool to import features even if there is
          already an entry in the GeoNames feature class and table.

          * DON'T_ALLOW_DUPLICATES-Prevents the tool from importing features if
          there is another feature with the same geometry and attributes in the
          GeoNames feature class or GeoNames table. This is the default.
      in_table (Table):
          The GeoNames table; this table should be in the working database."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GeoNamesToGeodatabase_topographic(*gp_fixargs((in_source, in_feature_class, in_allow_duplicates, in_table), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('GeodatabaseToShape_topographic', None)
def GeodatabaseToShape(in_features=None, output_folder=None, coded_value_domain_export_mode=None, conversion_method=None, create_empties=None):
    """GeodatabaseToShape_topographic(in_features;in_features..., output_folder, coded_value_domain_export_mode, conversion_method, create_empties)

        Exports one or more feature classes in a geodatabase to
        shapefiles.This tool has three modes of converting feature classes to
        shapefiles:
        defense, generic, and MGCP. Each mode controls how the output
        shapefiles are named. The defense and MGCP export modes follow Defense
        Mapping data model requirements. Generic mode uses the same logic as
        Feature Class To Feature Class.

     INPUTS:
      in_features (Feature Layer):
          The features used to create the shapefiles.
      output_folder (Folder):
          The folder that will contain the output shapefiles.
      coded_value_domain_export_mode (String):
          Indicates what method will be used to export coded domain values.

          * VALUES-Exports coded domain values as raw values. This is the
          default.

          * DESCRIPTIONS-Exports coded domain values using their descriptions
          rather than raw values.

          * VALUES_AND_DESCRIPTIONS-Exports coded domain values as raw values
          and string descriptions
      conversion_method (String):
          Indicates which conversion method will be applied.

          * DEFENSE_BY_SUBTYPE-Creates a shapefile based on subtype name,
          exports attributes applicable to that subtype, and removes trailing
          underscores from fields. This is the default.

          * DEFENSE_BY_FEATURECLASS-Creates a shapefile based on the feature
          class name and removes trailing underscores from fields.

          * GENERIC_BY_FEATURECLASS-Creates a shapefile for each feature class
          selected. The shapefile name matches the feature class name.

          * GENERIC_BY_SUBTYPE-Creates a shapefile for each subtype of the
          feature class selected. The shapefile name matches the subtype name.

          * MGCP-Creates a shapefile based on the feature class subtype. The
          shapefile is named using the geometry type and feature code. For
          example, the River subtype in the WatrcrsL feature class would be
          exported to a shapefile called LBH140.
      create_empties (Boolean):
          Indicates that the tool will create empty shapefiles if the input
          feature classes are also empty.

          * CREATE_EMPTIES-Create empty shapefiles if the corresponding feature
          classes to export are empty.

          * NO_CREATE_EMPTIES-Do no create empty shapefiles if the corresponding
          feature classes to export are empty. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GeodatabaseToShape_topographic(*gp_fixargs((in_features, output_folder, coded_value_domain_export_mode, conversion_method, create_empties), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('ImportMetadata_topographic', None)
def ImportMetadata(files=None, in_cell_features=None):
    """ImportMetadata_topographic(files;files..., in_cell_features)

        Imports Multinational Geospatial Co-production Program (MGCP)
        metadata into an MGCP database to perform maintenance on cells and
        subregions.

     INPUTS:
      files (File):
          The XML files that contain the metadata to import.
      in_cell_features (Feature Layer):
          The Cell feature class where the metadata will be imported."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportMetadata_topographic(*gp_fixargs((files, in_cell_features), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('LoadData_topographic', None)
def LoadData(in_cross_reference=None, in_sources=None, in_target=None, in_dataset_map_defs=None, row_level_errors=None):
    """LoadData_topographic(in_cross_reference, in_sources;in_sources..., in_target, {in_dataset_map_defs;in_dataset_map_defs...}, {row_level_errors})

        Moves features from one schema to another by loading data from a
        source to a target workspace.  Data mapping rules described in a
        cross-reference database are applied during the load.Data that matches
        the schema defined in the cross-reference database
        for the source is appended to the target workspace. The cross-
        reference database contains a DatasetMapping table that lists pairs of
        source and target dataset names. Each source and target name pair can
        have a WHERE clause and a subtype. The WHERE clause defines a subset
        of features in the source to append to the target. Subtype identifies
        a subtype in the target feature class into which features are loaded.

     INPUTS:
      in_cross_reference (Workspace):
          The path to a cross-reference database. .
      in_sources (Workspace):
          A list of workspaces that contain the source features to load into the
          target workspace.
      in_target (Workspace):
          The target workspace that contains the schema referenced in the cross-
          reference database. Source features are loaded into this workspace.
      in_dataset_map_defs {String}:
          The source to target feature class mapping list. The format of this
          string is id | SourceDataset | TargetDataset | WhereClause | Subtype.
      row_level_errors {Boolean}:
          Indicates if the tool will log errors that occur while inserting new
          rows into feature classes and tables in in_target.

          * ROW_LEVEL_ERROR_LOGGING-Log errors that occur during individual row-
          level inserts

          * NO_ROW_LEVEL_ERROR_LOGGING-Do not log errors that occur during
          individual row-level inserts. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.LoadData_topographic(*gp_fixargs((in_cross_reference, in_sources, in_target, in_dataset_map_defs, row_level_errors), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('UnzipCellAndImport_topographic', None)
def UnzipCellAndImport(Root_Folder=None, Target_Geodatabase=None):
    """UnzipCellAndImport_topographic(Root_Folder, Target_Geodatabase)

        Unzips and imports compressed Multinational Geospatial Co-production
        Program (MGCP) 1-degree-by-1-degree cell packages (*.zip) into a
        target geodatabase.

     INPUTS:
      Root_Folder (Folder):
          The root folder that contains one or more compressed shapefile cell
          packages in a .zip file.
      Target_Geodatabase (Workspace):
          The geodatabase where the unzipped shapefiles will be imported."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UnzipCellAndImport_topographic(*gp_fixargs((Root_Folder, Target_Geodatabase), True)))
        return retval
    except Exception as e:
        raise e


# Data Management\Topology toolset
@gptoolnotsupported
@gptooldoc('ExportTopology_topographic', None)
def ExportTopology(topology=None, location=None, file_name=None):
    """ExportTopology_topographic(topology, location, file_name)

        Exports a topology from a geodatabase to an .xml file. The .xml file
        can be used by the Import Topology tool to create a topology in a
        feature dataset. Both this tool and the Import Topology tool allow you
        to share and create topologies within different geodatabases. The .xml
        file contains a definition of a topology, including feature class
        names, topology ranks, topology rules, and cluster tolerance.

     INPUTS:
      topology (Topology / Topology Layer):
          An existing topology in a Defense Mapping geodatabase. All feature
          classes that participate in this topology will be listed in the output
          .xml file.
      location (Folder):
          The folder in which the .xml file will be written.
      file_name (String):
          The name of the topology .xml file that will be created by the tool."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportTopology_topographic(*gp_fixargs((topology, location, file_name), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('ImportTopology_topographic', None)
def ImportTopology(in_feature_dataset=None, topology_definition_file=None):
    """ImportTopology_topographic(in_feature_dataset, topology_definition_file)

        Creates a geodatabase topology from a definition .xml file generated
        by the Export Topology tool in the Topographic Production toolbox.
        Both this tool and the Export Topology tool allow you to share and
        create topologies within different geodatabases. The .xml file
        contains a definition of a topology, including feature class names,
        topology ranks, topology rules, and cluster tolerance.

     INPUTS:
      in_feature_dataset (Feature Dataset):
          The feature dataset in which the topology will be created. The
          feature dataset must contain the feature classes listed in the
          topology_definition_file.
      topology_definition_file (File):
          The .xml file that contains the topology definition."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportTopology_topographic(*gp_fixargs((in_feature_dataset, topology_definition_file), True)))
        return retval
    except Exception as e:
        raise e


# Data Management\Validation toolset
@gptoolnotsupported
@gptooldoc('GAIT_topographic', None)
def GAIT(in_features=None, gait_exe=None, folder=None, schema=None, project=None, format=None, metadata=None, silent=None, reviewer_workspace=None, specfile=None):
    """GAIT_topographic(in_features;in_features..., gait_exe, folder, schema, project, format, metadata, silent, {reviewer_workspace}, {specfile})

        Validates data using the Geospatial Analysis Integrity Tool (GAIT),
        checking geometry, feature codes, attribute values and domains, and
        metadata.

     INPUTS:
      in_features (Table View / Feature Layer):
          The features to validate.
      gait_exe (File):
          The path to the GAIT executable file.
      folder (Folder):
          The shapefile export directory.
      schema (String):
          The data model that corresponds to the data displayed in the input
          feature layer.
      project (String):
          The name of the project. The project contains validation information,
          such as the checks run on the data and the results.
      format (String):
          The set of checks to run on the data. This is specific to the data
          model listed in the attribution schema.
      metadata (String):
          The metadata mapping table that corresponds to the data model of the
          input feature layer and the attribution schema.

          * META_ESRI-Esri metadata

          * META_INGR-Intergraph metadata

          * META_MGCPNGA-MGCP NGA metadata
      silent (Boolean):
          Indicates the amount of output messages to return from GAIT.exe.

          * SILENT-Limit messaging from GAIT.exe. This is the default.

          * VERBOSE-Run GAIT.exe in verbose mode.
      reviewer_workspace {Workspace}:
          The workspace to write the output features. Each shapefile result
          record is written to the reviewer table in this workspace.
      specfile {File}:
          A file that defines custom checks."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GAIT_topographic(*gp_fixargs((in_features, gait_exe, folder, schema, project, format, metadata, silent, reviewer_workspace, specfile), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject, gptoolnotsupported
