# -*- coding: utf-8 -*-
#COPYRIGHT 2017 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""The Workflow Manager toolbox provides tools for working with
distributed Workflow Manager repositories as well as tools that
retrieve job-specific information useful for other data processing
tasks. With the tools in this toolbox, you can retrieve job version,
job's data workspace, replicate/synchronize Workflow Manager
repositories, and get a job's area of interest."""
__all__ = ['ClearJobReplicationInfo', 'CreateJobDataReplica', 'CreateJobs',
           'CreateNewJobs', 'CreateWorkflowDatabase', 'ExportJobData',
           'GetJobAOI', 'GetJobDataWorkspace', 'GetJobParentVersion',
           'GetJobVersion', 'ImportJobData', 'PostJobVersion',
           'SynchronizeJobData', 'UpgradeWorkflowDatabase']
__alias__ = 'wmx'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs, gptoolnotsupported
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
from arcpy import _wmx
from arcpy._wmx import *
__all__ += _wmx.__all__

# Configuration toolset
@gptoolnotsupported
@gptooldoc('ClearJobReplicationInfo_wmx', None)
def ClearJobReplicationInfo(Input_Repository_URL=None, Input_DatabasePath=None):
    """ClearJobReplicationInfo_wmx(Input_Repository_URL, {Input_DatabasePath})

        Deletes the replication information on a parent repository and sends
        a web service call to all the child repositories in the cluster.
        Consequently, the replication information is cleared from all the
        repositories participating in the cluster.

     INPUTS:
      Input_Repository_URL (String):
          The URL for the Workflow Manager Server Object as defined on the
          server.For example,
          http://ServerName/arcgis/rest/services/ServerObjectName/WMServer.
      Input_DatabasePath {File}:
          The Workflow Manager connection file (.jtc) for the database from
          which to delete the replication information. If no connection file is
          specified, the current default Workflow Manager database is used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ClearJobReplicationInfo_wmx(*gp_fixargs((Input_Repository_URL, Input_DatabasePath), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('CreateJobDataReplica_wmx', None)
def CreateJobDataReplica(Input_Parent_Repository_URL=None, Input_Parent_Repository_Name=None, Input_Multi_Name=None):
    """CreateJobDataReplica_wmx(Input_Parent_Repository_URL, Input_Parent_Repository_Name, Input_Multi_Name;Input_Multi_Name...)

        Replicates the Workflow Manager configuration from a parent
        repository to child repositories using Workflow Manager for Server.
        Each child repository becomes an identical copy (replica) of the
        parent repository. Learn more about Workflow Manager Replication

     INPUTS:
      Input_Parent_Repository_URL (String):
          The URL for the parent repository as the Workflow Manager service
          URL, for example,
          http://localhost/arcgis/rest/services/parent/wmserver.
      Input_Parent_Repository_Name (String):
          The name of the parent repository that will be distributing the
          Workflow Manager jobs and configuration elements.
      Input_Multi_Name (Value Table):
          The child repositories that will be updated with the parent repository
          configuration.

          * child_name-The name of the child repository.

          * connected-Specify "true" if the child is participating in connected
          replication and both parent and child workflow manager services are
          published and online. Specify "false" if the child is participating in
          disconnected replication. In this case, only the parent workflow
          manager service is published and online.

          * URL-If connected is "true", specify the URL of the child repository.
          If connected is "false", specify a folder location to contain the
          configuration file exported from the parent repository. This
          configuration file can be used with the Import Job Data tool to
          replicate the parent to this disconnected repository."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateJobDataReplica_wmx(*gp_fixargs((Input_Parent_Repository_URL, Input_Parent_Repository_Name, Input_Multi_Name), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('CreateWorkflowDatabase_wmx', None)
def CreateWorkflowDatabase(Input_Database_Connection=None, AOI_Spatial_Reference=None, Import_Configuration=None, Input_Custom_Configuration=None, User_Store=None):
    """CreateWorkflowDatabase_wmx(Input_Database_Connection, AOI_Spatial_Reference, Import_Configuration, {Input_Custom_Configuration}, {User_Store})

        Creates Workflow Manager schema and configures an enterprise
        geodatabase as the Workflow Manager database.The Workflow Manager
        database is used to store the job and
        configuration information for your work management system. Creating a
        new Workflow Manager database is an administrative activity that
        creates Workflow Manager schema in the specified enterprise
        geodatabase. The Workflow Manager database schema consists of system
        tables and one feature class that is used to store the geometries for
        the Area of Interest (AOI) for your jobs.The Workflow Manager system
        tables added by the Create Workflow
        Database tool are geodatabase tables and are registered with your
        enterprise geodatabase. As the Workflow Manager system tables are
        geodatabase tables, it is strongly advised that you not delete or
        modify these tables using your RDBMS tools.The Workflow Manager
        repository name is created based on the database
        instance name and the user name resulting in <instance
        name>_<username>. If operating system authentication is used, the user
        name of the current user logged in to the system is retrieved.

     INPUTS:
      Input_Database_Connection (Workspace):
          The location of the enterprise geodatabase connection file that will
          host the Workflow Manager schema and configuration. The connection
          file must connect directly to the database and the connection should
          be made as a database owner.
      AOI_Spatial_Reference (Coordinate System):
          The spatial reference of the AOI feature class. You can specify the
          spatial reference in several ways:

          * By inputting the path to a .prj file, such as
          c:/workspace/watershed.prj

          * By defining a spatial reference object prior to using this tool,
          such as AOI_Spatial_Reference =
          arcpy.SpatialReference("c:/data/Africa/Carthage.prj") or
          AOI_Spatial_Reference = arcpy.SpatialReference('WGS 1984'), which you
          then use as the spatial reference parameter
      Import_Configuration (String):
          The Workflow Manager elements to be imported in the new Workflow
          Manager database. The default import configuration option is Minimum
          Configuration.

          * Minimum Configuration-Imports the basic elements that the Workflow
          Manager system requires.

          * Quick Configuration-Includes the minimum configuration elements plus
          samples for several elements.

          * Custom Configuration-Specify a Workflow Manager configuration file
          in the Input Custom Configuration parameter, exported from a
          preexisting database.
      Input_Custom_Configuration {File}:
          A custom configuration file that was exported from a preexisting
          Workflow Manager database.
      User_Store {String}:
          The user store from which to retrieve the users and roles. The users
          can be imported from a portal and are assigned to roles created in the
          Workflow Manager repository. The portal user profile information
          cannot be edited using Workflow Manager Administrator. The users and
          roles can be created in the Workflow Manager repository using the
          TRADITIONAL option. When using the TRADITIONAL option, the users and
          roles may be imported from the Active Directory in Workflow Manager
          Administrator.

          * PORTAL-The users will be imported from the portal you are currently
          signed in to.

          * TRADITIONAL  -The users and roles will be created in the Workflow
          Manager repository using Workflow Manager Administrator. Users and
          roles can be imported from the Active Directory when this option is
          used. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateWorkflowDatabase_wmx(*gp_fixargs((Input_Database_Connection, AOI_Spatial_Reference, Import_Configuration, Input_Custom_Configuration, User_Store), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('ExportJobData_wmx', None)
def ExportJobData(Input_Folder=None, Input_DatabasePath=None, Input_Repository_Name=None, Input_Export_Since=None, Input_Export_Until=None):
    """ExportJobData_wmx(Input_Folder, {Input_DatabasePath}, {Input_Repository_Name}, {Input_Export_Since}, {Input_Export_Until})

        This tool will export the Workflow Manager repository to a .jxl file
        in the specified folder location. The .jxl file will contain all the
        configuration information for the repository as well as information
        about all the jobs. The .jxl file can be imported into another
        Workflow Manager repository using the Import Job Data tool.

     INPUTS:
      Input_Folder (Folder):
          The location of the JXL file output from the tool. This folder can be
          on a local or a network drive.
      Input_DatabasePath {File}:
          The Workflow Manager connection file for the database to be exported.
          If no connection file is specified, the current default Workflow
          Manager database in the project is used.
      Input_Repository_Name {String}:
          The name of the Workflow Manager repository that contains the
          configuration to be shared. If repository name is not specified, the
          current default Workflow Manager repository name is used.
      Input_Export_Since {Date}:
          By specifying a date, the JXL exported will only contain changes that
          occurred between the specified time and the current date. The input
          should be in UTC time format.
      Input_Export_Until {Date}:
          By specifying a date, the JXL exported will only contain changes that
          occurred between Export Since and the specified time. The input should
          be in UTC time format."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportJobData_wmx(*gp_fixargs((Input_Folder, Input_DatabasePath, Input_Repository_Name, Input_Export_Since, Input_Export_Until), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('ImportJobData_wmx', None)
def ImportJobData(Input_File=None, Input_Merge=None, Input_DatabasePath=None, Input_Repository_Name=None):
    """ImportJobData_wmx(Input_File, Input_Merge, {Input_DatabasePath}, {Input_Repository_Name})

        This tool allows you to import Workflow Manager configuration and job
        information found in a repository into a destination repository. This
        tool is most useful for setting up a repository similar to an existing
        repository, disconnected repository replica creation, and change
        synchronization.

     INPUTS:
      Input_File (File):
          The JXL file that contains all the jobs and configuration elements
          generated using the Export Job Data tool.
      Input_Merge (Boolean):
          Choose whether contents of the destination workflow manager
          repository should be combined instead of being overwritten with the
          contents of the input configuration file.

          * COMBINE-Combine the contents of the destination Workflow Manager
          database with the contents of the input configuration file.

          * REPLACE-Replace the entire contents of the destination Workflow
          Manager database with the contents of the input configuration file.
      Input_DatabasePath {File}:
          The Workflow Manager connection file that contains the connection
          information to the destination repository. If no connection file is
          specified, the current default workflow manager database in the
          project is used.
      Input_Repository_Name {String}:
          The name of the repository as specified in the Workflow Manager
          system settings. This is a name that should be unique with all the
          repositories in your cluster. If the repository name is not specified,
          the current default workflow manager repository name will be used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportJobData_wmx(*gp_fixargs((Input_File, Input_Merge, Input_DatabasePath, Input_Repository_Name), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('SynchronizeJobData_wmx', None)
def SynchronizeJobData(Input_Parent_Repository_URL=None, Input_Parent_Repository_Name=None, Input_Multi_Name=None):
    """SynchronizeJobData_wmx(Input_Parent_Repository_URL, Input_Parent_Repository_Name, Input_Multi_Name;Input_Multi_Name...)

        This tool synchronizes multiple Workflow Manager repositories
        participating in a Workflow Manager Cluster. The tool performs two-way
        synchronization; changes from the child repositories are sent to the
        parent repository and changes from the parent are sent to all child
        repositories. This tool requires that you have Workflow Manager for
        Server
        installed and configured across all participating nodes.Learn more
        about Workflow Manager replication

     INPUTS:
      Input_Parent_Repository_URL (String):
          The URL for the parent repository will be the Workflow Manager server
          URL, for example,
          http://localhost/arcgis/rest/services/parent/wmserver.
      Input_Parent_Repository_Name (String):
          The parent repository that will be distributing the Workflow Manager
          jobs and configuration elements.
      Input_Multi_Name (Value Table):
          The child repositories that will be updated with the parent repository
          configuration.

          * child_repository-The name of the child repository. This must be a
          connected repository.

          * connected-The only accepted value is "true". If any other value is
          entered, the child will not be synchronized.

          * URL-The URL of the child repository.

          * last_sync_time-The date and time in the system format. For example,
          if your system data and time format is MM:DD:YY HH:MM:SS, the value
          would be 08/01/2013 11:30:45."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SynchronizeJobData_wmx(*gp_fixargs((Input_Parent_Repository_URL, Input_Parent_Repository_Name, Input_Multi_Name), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('UpgradeWorkflowDatabase_wmx', None)
def UpgradeWorkflowDatabase(Input_Database_Connection=None, User_Store=None):
    """UpgradeWorkflowDatabase_wmx(Input_Database_Connection, {User_Store})

        The Upgrade Workflow Database tool upgrades an existing Workflow
        Manager database with the latest schema and configuration. The
        Workflow Manager database is used to store the job and configuration
        information for your work management system and one feature class that
        is used to store the geometries for the Location of Interest (LOI) for
        your jobs.In Workflow Manager databases created with an earlier
        version than
        10.3, a group named Administrator is created with the
        AdministratorAccess privilege. The user running the tool is added to
        the Administrator group, which grants the user administrator access.
        For more information about Privileges, see Privileges. Administrator
        access means the current user can connect to the selected database
        through the Workflow Manager Administrator to make edits to components
        of your system. The existing Workflow Manager system settings are
        preserved during the upgrade.The Workflow Manager system tables are
        geodatabase tables and are
        registered with your enterprise geodatabase. Thus, it is strongly
        advised that you not delete or modify these tables using your RDBMS
        tools.If upgrading a 10.0 Workflow Manager database, see Upgrading an
        existing Workflow Manager system for additional instructions.

     INPUTS:
      Input_Database_Connection (Workspace):
          The location of the enterprise geodatabase connection file to the
          Workflow Manager database, which contains Workflow Manager system
          tables. The connection file must connect directly to the database and
          the connection should be made as a database owner.
      User_Store {String}:
          The user store from which to retrieve the users and roles. The users
          can be imported from a portal and are assigned to roles created in the
          Workflow Manager repository. The portal user profile information
          cannot be edited using Workflow Manager Administrator. The users and
          roles can be created in the Workflow Manager repository using the
          Traditional option. When using the Traditional option, the users and
          roles may be imported from the Active Directory in Workflow Manager
          Administrator.If no option is selected, Traditional is used by
          default.

          * PORTAL-The users will be imported from the portal you are currently
          signed in to.

          * TRADITIONAL-The users and roles will be created in the Workflow
          Manager repository using Workflow Manager Administrator. Users and
          roles can be imported from the Active Directory when this option is
          used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpgradeWorkflowDatabase_wmx(*gp_fixargs((Input_Database_Connection, User_Store), True)))
        return retval
    except Exception as e:
        raise e


# Jobs toolset
@gptoolnotsupported
@gptooldoc('CreateJobs_wmx', None)
def CreateJobs(Input_DatabasePath=None, Job_Types=None, Number_of_Jobs=None, Users=None, Priority_of_Jobs=None, Feature_Layer_AOI=None, Union_option=None):
    """CreateJobs_wmx(Input_DatabasePath, Job_Types, Number_of_Jobs, {Users}, {Priority_of_Jobs}, {Feature_Layer_AOI}, {Union_option})

        You can create one or more jobs of the selected job type and assign
        the jobs to a user. The created jobs can be given a priority and have
        an area of interest (AOI) defined from a feature layer or feature
        class.The CreateJob privilege is required to create jobs.This is a
        deprecated tool. This functionality has been replaced with
        the Create New Jobs tool that now creates jobs with group assignment
        and point of interest as well.

     INPUTS:
      Input_DatabasePath (File):
          The Workflow Manager database connection file that contains the job
          type information. If no connection file is specified, the current
          default workflow manager database is used.
      Job_Types (String):
          The job type to be used for creating the new job.
      Number_of_Jobs (Long):
          Number of new jobs to be created. This input is ignored if the
          Feature_Layer_AOI parameter has a value or if Union_option = "UNION"
          is selected.
      Users {String}:
          The user the new jobs will be assigned to. If no value is specified,
          the default value configured in the job type is used. The user or
          group the new jobs will be assigned to. If no value is
          specified, the default value configured in the job type is used.
      Priority_of_Jobs {String}:
          Priority of the jobs created. If no priority is specified, the
          default value configured in the job type is used.
      Feature_Layer_AOI {Feature Layer}:
          The polygon features whose geometry will be used to create the Area
          of Interest (AOI) of the new jobs. One job will be created for each
          feature in the layer unless Union_option = "UNION".
      Union_option {Boolean}:
          Choose whether to create one job with the union of all AOI polygons.

          * UNION-Generate one union polygon from the AOI polygons and create
          only one job regardless of the input number of jobs.

          *  NO_UNION-Each AOI polygon is used to generate one job. The total
          number of jobs created is equal to the total number of polygons in the
          feature layer."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateJobs_wmx(*gp_fixargs((Input_DatabasePath, Job_Types, Number_of_Jobs, Users, Priority_of_Jobs, Feature_Layer_AOI, Union_option), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('CreateNewJobs_wmx', None)
def CreateNewJobs(Input_DatabasePath=None, Job_Type=None, Number_of_Jobs=None, Assignment_Type=None, Assign_To=None, Priority=None, Feature_Layer_LOI=None, Union=None):
    """CreateNewJobs_wmx(Input_DatabasePath, Job_Type, Number_of_Jobs, {Assignment_Type}, {Assign_To}, {Priority}, {Feature_Layer_LOI}, {Union})

        You can create one or more jobs of the selected job type and assign
        the jobs to a user or a user group. The created jobs can be given a
        priority and assigned polygon or point location of interest (LOI).The
        CreateJob privilege is required to create jobs.

     INPUTS:
      Input_DatabasePath (File):
          The Workflow Manager database connection file that contains the job
          type information. If no connection file is specified, the current
          default workflow manager database is used.
      Job_Type (String):
          The job type to be used for creating the new job.
      Number_of_Jobs (Long):
          Number of new jobs to be created. This input is ignored if the
          Feature_Layer_LOI parameter has a value or if Union = "UNION".
      Assignment_Type {String}:
          The assignment type to assign new jobs. If no value is specified, the
          default value configured in the job type is used.

          * Groups-The new jobs will be assigned to a group.

          * Users-The new jobs will be assigned to a user.

          * Unassigned-The new jobs will be unassigned.
      Assign_To {String}:
          The user or group the new jobs will be assigned to. The value is
          restricted to user or group based on the selected assignment type.
      Priority {String}:
          Priority of the jobs created. If no priority is specified, the
          default value configured in the job type is used.
      Feature_Layer_LOI {Feature Layer}:
          The polygon, point, or multipoint features whose geometry will be
          used to create the Location of Interest (LOI) of the new jobs. One job
          will be created for each feature in the layer unless Union = "UNION".
      Union {Boolean}:
          Choose whether to create one job with the union of all polygons,
          point, or multipoint in the input feature layer as the LOI of the job.

          * UNION-Generate one union polygon or multipont feature from the LOI
          features and create only one job regardless of the input number of
          jobs.

          *  NO_UNION-Each feature in the input layer is used to generate the
          LOI of one job. The total number of jobs created is equal to the total
          number of input features. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateNewJobs_wmx(*gp_fixargs((Input_DatabasePath, Job_Type, Number_of_Jobs, Assignment_Type, Assign_To, Priority, Feature_Layer_LOI, Union), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('GetJobAOI_wmx', None)
def GetJobAOI(Input_JobID=None, aoi_Layer=None, Input_DatabasePath=None):
    """GetJobAOI_wmx(Input_JobID, aoi_Layer, {Input_DatabasePath})

        Gets the job's location of interest (LOI) as a feature layer. The
        output layer has either the polygon representing the area of interest
        (AOI) of the job or point representing the point of interest (POI) of
        the job.

     INPUTS:
      Input_JobID (String):
          The ID of the job whose AOI is to be retrieved.
      Input_DatabasePath {File}:
          The Workflow Manager database connection file for the input job. If
          no connection file is specified, the current default workflow manager
          database in the project is used.

     OUTPUTS:
      aoi_Layer (Feature Layer):
          The layer name for the location of interest retrieved. The output
          layer has either the polygon representing the area of interest (AOI)
          of the job or point representing the point of interest (POI) of the
          job."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GetJobAOI_wmx(*gp_fixargs((Input_JobID, aoi_Layer, Input_DatabasePath), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('GetJobDataWorkspace_wmx', None)
def GetJobDataWorkspace(Input_JobID=None, Input_DatabasePath=None, Input_SDEFileLocation=None):
    """GetJobDataWorkspace_wmx(Input_JobID, {Input_DatabasePath}, {Input_SDEFileLocation})

        Gets the job data workspace as an enterprise geodatabase connection
        file. This tool is typically used in ModelBuilder to retrieve the
        connection file for use as an input to other tools such as Reconcile
        Versions in the model.

     INPUTS:
      Input_JobID (String):
          The ID for the job whose data workspace connection is to be
          retrieved.
      Input_DatabasePath {File}:
          The Workflow Manager database connection file that contains the job
          information. If no connection file is specified, the current default
          workflow manager database in the project is used.
      Input_SDEFileLocation {Folder}:
          The job's data workspace connection file will be written to the
          specified folder."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GetJobDataWorkspace_wmx(*gp_fixargs((Input_JobID, Input_DatabasePath, Input_SDEFileLocation), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('GetJobParentVersion_wmx', None)
def GetJobParentVersion(Input_JobID=None, Input_DatabasePath=None):
    """GetJobParentVersion_wmx(Input_JobID, {Input_DatabasePath})

        Gets the parent version of a job as an enterprise geodatabase
        connection file to be used for posting edits in a geoprocessing model
        to the correct parent version.

     INPUTS:
      Input_JobID (String):
          The ID for the job's parent version to be retrieved.
      Input_DatabasePath {File}:
          The Workflow Manager database connection file that contains the job
          information. If no connection file is specified, the current default
          workflow manager database in the project is used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GetJobParentVersion_wmx(*gp_fixargs((Input_JobID, Input_DatabasePath), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('GetJobVersion_wmx', None)
def GetJobVersion(Input_JobID=None, Input_DatabasePath=None):
    """GetJobVersion_wmx(Input_JobID, {Input_DatabasePath})

        Gets the job version as an enterprise geodatabase connection file to
        process data in a version.

     INPUTS:
      Input_JobID (String):
          The ID for the job whose version is to be retrieved.
      Input_DatabasePath {File}:
          The Workflow Manager database connection file that contains the job
          information. If no connection file is specified, the current default
          workflow manager database in the project is used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GetJobVersion_wmx(*gp_fixargs((Input_JobID, Input_DatabasePath), True)))
        return retval
    except Exception as e:
        raise e

@gptoolnotsupported
@gptooldoc('PostJobVersion_wmx', None)
def PostJobVersion(Input_JobID=None, Input_DatabasePath=None):
    """PostJobVersion_wmx(Input_JobID, {Input_DatabasePath})

        Post the current version edits to the parent version of the job.

     INPUTS:
      Input_JobID (String):
          The ID for the job whose edits from the job's version are going to be
          posted to it's parent version.
      Input_DatabasePath {File}:
          The Workflow Manager database connection file that contains the job
          information. If no connection file is specified, the current default
          workflow manager database will be used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.PostJobVersion_wmx(*gp_fixargs((Input_JobID, Input_DatabasePath), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject, gptoolnotsupported